/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { withKnobs, boolean, number } from '@storybook/addon-knobs';

import SmileDatePicker from './smile-date-picker.vue';
import SmileTimePicker from './smile-time-picker.vue';
import SmileAppointmentScheduler from './smile-appointment-scheduler.vue';
import componentDocs from './smile-appointment-scheduler.md';

const times = [
  '9:00',
  '9:30',
  '10:00',
  '10:30',
  '11:00',
  '11:30',
  '12:00',
  '12:30',
  '13:00',
  '13:30',
  '14:00',
  '14:30',
  '15:00',
  '15:30',
  '16:00',
  '16:30',
];
const timePatternOne = Array(16)
  .fill(null)
  .map((_, index) => ({
    time: times[index],
    dateTimeObject: new Date().setHours(times[index].split(':')[0], times[index].split(':')[1]),
    disabled: !((index + 1) % 2),
  }));
const timePatternTwo = Array(16)
  .fill(null)
  .map((_, index) => ({
    time: times[index],
    dateTimeObject: new Date().setHours(times[index].split(':')[0], times[index].split(':')[1]),
    disabled: !((index + 1) % 3),
  }));
const timePatternThree = Array(16)
  .fill(null)
  .map((_, index) => ({
    time: times[index],
    dateTimeObject: new Date().setHours(times[index].split(':')[0], times[index].split(':')[1]),
    disabled: !((index + 1) % 5),
  }));
const timePatternFour = Array(16)
  .fill(null)
  .map((_, index) => ({
    time: times[index],
    dateTimeObject: new Date().setHours(times[index].split(':')[0], times[index].split(':')[1]),
  }));

const timePatterns = [timePatternOne, timePatternTwo, timePatternThree, timePatternFour];

const days = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'];
const calendar = Array(14)
  .fill(null)
  .map((_, index) => ({
    date: {
      day: days[index % 7],
      date: index,
      disabled: (index + 1) % 3 === 0,
      counter: 0,
    },
    times: timePatterns[Math.floor(Math.random() * 4)],
  }));
calendar[0].date.description = 'Today';
calendar[1].date.description = 'Tomorrow';

storiesOf('Vue Components / SmileAppointmentScheduler', module)
  .addDecorator(withKnobs)
  .addParameters({ notes: { componentDocs } })
  .add(
    'Date picker',
    () => ({
      components: { SmileDatePicker },
      props: {
        length: {
          type: Number,
          default: number('Length', 14),
        },
        responsive: {
          type: Boolean,
          default: boolean('Responsive mode', true),
        },
        showScrollbar: {
          type: Boolean,
          default: boolean('Show scrollbar', false),
        },
        showArrows: {
          type: Boolean,
          default: boolean('Show arrows', true),
        },
      },
      data() {
        return {
          data: calendar,
          selectedDate: 1,
        };
      },
      computed: {
        config() {
          return {
            responsive: this.responsive,
            showScrollbar: this.showScrollbar,
            showArrows: this.showArrows,
          };
        },
      },
      template: `
        <div>
          <smile-date-picker :dates="data.slice(0, length).map(i=>i.date)" :config="config" v-model="selectedDate"/>
        </div>`,
    }),
    { info: true }
  )
  .add(
    'Time picker',
    () => ({
      components: { SmileTimePicker },
      props: {
        length: {
          type: Number,
          default: number('Length', 16),
        },
        responsive: {
          type: Boolean,
          default: boolean('Responsive mode', true),
        },
        showScrollbar: {
          type: Boolean,
          default: boolean('Show scrollbar', false),
        },
        showArrows: {
          type: Boolean,
          default: boolean('Show arrows', true),
        },
        convertToTwelveHourTime: {
          type: Boolean,
          default: boolean('Convert 24 hour to 12 hour time', true),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', false),
        },
      },
      data() {
        return {
          data: timePatternTwo,
          selectedTime: 0,
        };
      },
      computed: {
        config() {
          return {
            responsive: this.responsive,
            showScrollbar: this.showScrollbar,
            showArrows: this.showArrows,
            convertToTwelveHourTime: this.convertToTwelveHourTime,
            legacyDesign: this.legacyDesign,
          };
        },
      },
      template: `
        <div>
          <smile-time-picker :legacy-design="legacyDesign" :times="data.slice(0, length)" :config="config" v-model="selectedTime"/>
        </div>`,
    }),
    { info: true }
  )
  .add(
    'Time picker legacy design',
    () => ({
      components: { SmileTimePicker },
      props: {
        length: {
          type: Number,
          default: number('Length', 16),
        },
        responsive: {
          type: Boolean,
          default: boolean('Responsive mode', true),
        },
        showScrollbar: {
          type: Boolean,
          default: boolean('Show scrollbar', false),
        },
        showArrows: {
          type: Boolean,
          default: boolean('Show arrows', true),
        },
        convertToTwelveHourTime: {
          type: Boolean,
          default: boolean('Convert 24 hour to 12 hour time', true),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', true),
        },
      },
      data() {
        return {
          data: timePatternTwo,
          selectedTime: 0,
        };
      },
      computed: {
        config() {
          return {
            responsive: this.responsive,
            showScrollbar: this.showScrollbar,
            showArrows: this.showArrows,
            convertToTwelveHourTime: this.convertToTwelveHourTime,
            legacyDesign: this.legacyDesign,
          };
        },
      },
      mounted() {
        if (!this.legacyDesign) {
          this.legacyDesign = true;
        }
      },
      template: `
        <div>
          <smile-time-picker :legacy-design="legacyDesign" :times="data.slice(0, length)" :config="config" v-model="selectedTime"/>
        </div>`,
    }),
    { info: true }
  )
  .add(
    'Appointment picker',
    () => ({
      components: { SmileAppointmentScheduler },
      props: {
        responsive: {
          type: Boolean,
          default: boolean('Responsive mode', true),
        },
        showScrollbar: {
          type: Boolean,
          default: boolean('Show scrollbar', false),
        },
        showArrows: {
          type: Boolean,
          default: boolean('Show arrows', true),
        },
        updateData: {
          type: Boolean,
          default: boolean('Change calendar data', false),
        },
        convertToTwelveHourTime: {
          type: Boolean,
          default: boolean('Convert 24 hour to 12 hour time', true),
        },
      },
      data() {
        return {
          data: calendar,
          model: {
            date: 0,
            time: 0,
          },
        };
      },
      computed: {
        config() {
          return {
            responsive: this.responsive,
            showScrollbar: this.showScrollbar,
            showArrows: this.showArrows,
            convertToTwelveHourTime: this.convertToTwelveHourTime,
          };
        },
        counter() {
          this.calendar[0].date.counter = !!this.updateData;
        },
      },
      template: `
        <div>
          <smile-appointment-scheduler v-model="model" :appointments="data" :dateConfig="config" :timeConfig="config"/>
        </div>`,
    }),
    { info: true }
  );
