/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { withKnobs, select, text } from '@storybook/addon-knobs';
import SmileAudio from './smile-audio.vue';
import componentDocs from './smile-audio.md';

const CLOUDINARY = '//res.cloudinary.com/smiledirectclub/video/upload/br_64k/v1610393213/';

storiesOf('Vue Components / SmileAudio', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'Smile Audio Component',
    () => ({
      components: { SmileAudio },
      props: {
        autoplay: {
          type: Boolean,
          required: false,
          default: select('Autoplay', [true, false], false),
        },
        baseUrl: {
          type: String,
          required: false,
          default: text('Base URL', CLOUDINARY),
        },
        controls: {
          type: Boolean,
          required: false,
          default: select('Controls', [true, false], true),
        },
        disableRemotePlayback: {
          type: Boolean,
          required: false,
          default: select('Disable Remote Playback', [true, false], false),
        },
        loop: {
          type: Boolean,
          required: false,
          default: select('Loop', [true, false], false),
        },
        preload: {
          type: String,
          required: false,
          default: select('Preload', ['none', 'metadata', 'auto'], 'metadata'),
        },
        projectName: {
          type: String,
          required: false,
          default: text('Project Name', 'bell-ringing'),
        },
      },
      computed: {
        audioName() {
          return this.baseUrl + this.projectName;
        },
      },
      template: `
      <smile-audio
        :autoplay="autoplay"
        :controls="controls"
        :disableRemotePlayback="disableRemotePlayback"
        :loop="loop"
        :preload="preload"
        controlsList="nodownload"
        :src="audioName + '.mp3'"
      />
    `,
    }),
    { info: true }
  );
