/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';

import { action } from '@storybook/addon-actions';
import {
  withKnobs, select, boolean, text,
} from '@storybook/addon-knobs';

import SmileButton from './SmileButton.vue';
import componentDocs from './smile-button.md';

storiesOf('Vue Components / SmileButton', module)
  .addDecorator(withKnobs)
  .addParameters({ notes: { componentDocs } })
  .add(
    'SmileButton',
    () => ({
      components: { SmileButton },
      props: {
        buttonText: {
          type: String,
          default: text('buttonText', 'Prop text takes priority over slot'),
        },
        buttonSlot: {
          type: String,
          default: text('Slot Text', 'If no prop text, then slot will render'),
        },
        buttonStyles: {
          type: String,
          default: select('buttonStyles', ['is-primary', 'is-white', 'is-text', 'is-ghost'], 'is-primary'),
        },
        buttonSize: {
          type: String,
          default: select('buttonSize', ['', 'is-large', 'is-medium', 'is-small'], ''),
        },
        tag: {
          type: String,
          default: select('buttonTag', ['button', 'a', 'nuxt-link']),
        },
        buttonLink: {
          type: String,
          default: text('buttonLink', 'https://google.com'),
        },
        iconLeft: {
          type: String,
          default: text('iconLeft', ''),
        },
        iconRight: {
          type: String,
          default: text('iconRight', ''),
        },
        nativeType: {
          type: String,
          default: text('nativeType', 'button'),
        },
        loading: {
          type: Boolean,
          default: boolean('loading'),
        },
        outlined: {
          type: Boolean,
          default: boolean('outlined'),
        },
        focused: {
          type: Boolean,
          default: boolean('focused'),
        },
        inverted: {
          type: Boolean,
          default: boolean('inverted'),
        },
        hovered: {
          type: Boolean,
          default: boolean('hovered'),
        },
        active: {
          type: Boolean,
          default: boolean('active'),
        },
        selected: {
          type: Boolean,
          default: boolean('selected'),
        },
        expanded: {
          type: Boolean,
          default: boolean('expanded'),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign'),
        },
        rounded: {
          type: Boolean,
          default: boolean('rounded', true)
        }
      },
      methods: {
        clickHandler: action('clicked, custom method would run here if needed for a standard button element'),
      },
      template: `
      <smile-button
        :button-text="buttonText"
        :button-styles="buttonStyles"
        :button-size="buttonSize"
        :loading="loading"
        :outlined="outlined"
        :focused="focused"
        :inverted="inverted"
        :hovered="hovered"
        :active="active"
        :expanded="expanded"
        :icon-left="iconLeft"
        :icon-right="iconRight"
        :native-type="nativeType"
        :button-tag="tag"
        :button-link="buttonLink"
        :legacy-design="legacyDesign"
        :on-click="clickHandler"
        :rounded="rounded"
      >
        {{ buttonSlot }}
      </smile-button>
      `,
    }),
    { info: true },
  );
