# Smile Button

Our `smile-button` component is based off of and extended from Buefy's `b-button` component. https://buefy.org/documentation/button - Most of the prop names match the Buefy documentation with the exception of a few.

## Available Props

| Prop            | Type     | Required/Optional | Default value          | Description                                                                                                                                                                                                                  |
| --------------- | -------- | ----------------- | ---------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `button-text`   | String   | Optional          | -                      | Will render in place of button slot text if used. (Tied to Buefy's `label` prop.)                                                                                                                                            |
| `button-styles` | String   | Optional          | `is-primary` (Blurple) | Style treatment options for the button. Available options: `is-primary`, `is-white`, `is-text`, and `is-ghost`. (Tied to Buefy's `type` prop.)                                                                               |
| `button-size`   | String   | Optional          | -                      | Buttons are "large" size by default. Using the `is-large` prop will make buttons automatically convert to full-width on mobile screens. Available sizes: `is-large`, `is-medium`, `is-small`. (Tied to Buefy's `size` prop.) |
| `button-link`   | String   | Optional          | `#`                    | A url or path that the button should take the user to when clicked. Using this prop will automagically render the button tag as an `a`. You can also use `button-tag="a"` and `href=""` separately.                          |
| `button-tag`    | String   | Optional          | `button`               | Defines the HTML tag rendered for the button. Available options: `button`, `a`, `input`, `nuxt-link`. (Tied to Buefy's `tag` prop.)                                                                                          |
| `icon-left`     | String   | Optional          | -                      | Inserts an icon on the left side of the button. Icon names from Feather: https://feathericons.com/                                                                                                                           |
| `icon-right`    | String   | Optional          | -                      | Inserts an icon on the right side of the button. Icon names from Feather: https://feathericons.com/                                                                                                                          |
| `native-type`   | String   | Optional          | -                      | Populates/adds the native HTML `type` attribute.                                                                                                                                                                             |
| `loading`       | Boolean  | Optional          | `false`                | Displays the button in a "loading" visual state.                                                                                                                                                                             |
| `outlined`      | Boolean  | Optional          | `false`                | Makes the button an outline button.                                                                                                                                                                                          |
| `focused`       | Boolean  | Optional          | `false`                | Adds the `is-focused` class to force the visual "focus" state of the button                                                                                                                                                  |
| `inverted`      | Boolean  | Optional          | `false`                | Inverts the button's color scheme                                                                                                                                                                                            |
| `hovered`       | Boolean  | Optional          | `false`                | Adds the `is-hovered` class to force the visual "hover" state of the button                                                                                                                                                  |
| `active`        | Boolean  | Optional          | `false`                | Adds the `is-active` class to force the visual "active" state of the button                                                                                                                                                  |
| `selected`      | Boolean  | Optional          | `false`                |                                                                                                                                                                                                                              |
| `expanded`      | Boolean  | Optional          | `false`                | Makes the button full width of its container by adding the `is-fullwidth` class.                                                                                                                                             |
| `legacy-design` | Boolean  | Optional          | `false`                | Makes the component look like our legacy designs.                                                                                                                                                                            |
| `on-click`      | Function | Optional          | `() => {}`             | Define a callback function to run when the button is clicked. This is passed to the `@click` (or `v-on:click`) handler.                                                                                                      |
| `rounded`       | Boolean  | Optional          | `true`                 | Makes the button rounded adding the `is-rounded` class.                                                                                                                                                                      |

## Basic Usage

### Default with onClick

```html
<smile-button on-click="myClickFunction()">Button text</smile-button>
```

### Default with link

```html
<smile-button button-link="https://google.com">Button text</smile-button>
```

### Getting fancy

```html
<smile-button
	button-tag="nuxt-link"
	button-link="/smileshops/"
	button-styles="is-white"
	button-size="is-medium"
	icon-right="chevron-right"
	outlined
>
	Button text
</smile-button>
```
