/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';

import { action } from '@storybook/addon-actions';
import {
  withKnobs,
  select,
  boolean,
  text,
} from '@storybook/addon-knobs';

import SmileCheckbox from './smile-checkbox.vue';
import componentDocs from './smile-checkbox.md';

storiesOf('Vue Components / SmileCheckbox', module)

  .addDecorator(withKnobs({
    escapeHTML: false,
  }))
  .addParameters({ notes: { componentDocs } })
  .add('Smile Checkbox component', () => ({
    components: { SmileCheckbox },
    props: {
      innerhtml: {
        default: text('Content', 'Example text with <a href="#">link</a>'),
        type: String,
      },
      trueValue: {
        type: String,
        default: select('True value', ['true', 'Object', 'Array', 'String', 'Number'], 'True'),
      },
      falseValue: {
        type: String,
        default: select('False value', ['false', 'Object', 'Array', 'String', 'Number'], 'false'),
      },
      disabled: {
        type: Boolean,
        default: boolean('Disabled'),
      },
      legacyDesign: {
        type: Boolean,
        default: boolean('legacyDesign', false),
      }
    },
    methods: {
      action: action('checkbox checked'),
      returnType(type) {
        let val;
        switch (type) {
          case 'false':
            val = false;
            break;
          case 'true':
            val = true;
            break;
          case 'Object':
            val = { example: true };
            break;
          case 'Array':
            val = ['1', '2', '3'];
            break;
          case 'String':
            val = 'checkbox text';
            break;
          case 'Number':
            val = 7;
            break;
          default:
            val = '';
            break;
        }
        return val;
      },
    },
    template: `
        <smile-checkbox
          @input="action"
          :disabled="disabled"
          :true-value="returnType(trueValue)"
          :false-value="returnType(falseValue)"
          :legacy-design="legacyDesign"
        >
          <div v-html="innerhtml"/>
        </smile-checkbox>
      `,
  }), { info: true })
  .add('Smile Checkbox group', () => ({
    components: { SmileCheckbox },
    props: {
      nativeValue1: {
        type: String,
        default: text('Native value 1', 'nativeValue1'),
      },
      nativeValue2: {
        type: String,
        default: text('Native value 2', 'nativeValue2'),
      },
      legacyDesign: {
        type: Boolean,
        default: boolean('legacyDesign', false),
      }
    },
    data() {
      return {
        check: [],
      };
    },
    methods: {
      action: action('checkbox checked'),
    },
    template: `
        <div>
          <p>selected options: {{check}}</p>
          <smile-checkbox
            v-model="check"
            @input="action"
            :native-value="nativeValue1"
            :legacy-design="legacyDesign"
          >
              Native value 1
          </smile-checkbox>
          <smile-checkbox
            v-model="check"
            @input="action"
            :native-value="nativeValue2"
            :legacy-design="legacyDesign"
          >
              Native value 2
          </smile-checkbox>
          <smile-checkbox
            v-model="check"
            @input="action"
            native-value="Value 3"
            disabled
            :legacy-design="legacyDesign"
          >
              Native value 3
          </smile-checkbox>
        </div>
      `,
  }), { info: true })
  .add('Smile Checkbox with Legacy design', () => ({
    components: { SmileCheckbox },
    props: {
      innerhtml: {
        default: text('Content', 'Example text with <a href="#">link</a>'),
        type: String,
      },
      trueValue: {
        type: String,
        default: select('True value', ['true', 'Object', 'Array', 'String', 'Number'], 'True'),
      },
      falseValue: {
        type: String,
        default: select('False value', ['false', 'Object', 'Array', 'String', 'Number'], 'false'),
      },
      disabled: {
        type: Boolean,
        default: boolean('Disabled'),
      },
      legacyDesign: {
        type: Boolean,
        default: boolean('legacyDesign', true),
      },
    },
    mounted() {
      if (!this.legacyDesign) {
        this.legacyDesign = true;
      }
    },
    methods: {
      action: action('checkbox checked'),
      returnType(type) {
        let val;
        switch (type) {
          case 'false':
            val = false;
            break;
          case 'true':
            val = true;
            break;
          case 'Object':
            val = { example: true };
            break;
          case 'Array':
            val = ['1', '2', '3'];
            break;
          case 'String':
            val = 'checkbox text';
            break;
          case 'Number':
            val = 7;
            break;
          default:
            val = '';
            break;
        }
        return val;
      },
    },
    template: `
        <smile-checkbox
          @input="action"
          :disabled="disabled"
          :true-value="returnType(trueValue)"
          :false-value="returnType(falseValue)"
          :legacy-design="legacyDesign"
        >
          <div v-html="innerhtml"/>
        </smile-checkbox>
      `,
  }), { info: true })
