# Smile Collapse

This component can be used to wrap any content, including other components, to present them inside an expandable / collapsible panel.

## Props

Prop | Type | Required/Optional | Default value | Description
| --- | --- | --- | --- | --- |
| `isOpen` | Boolean | Optional | `false` | Adjust this prop to manually override the "open" state of the collapse. |
| `removeContainer` | Boolean | Optional | `false` | Changes the visual design of the component to have only a bottom border and no background color or container. |
| `legacyDesign` | Boolean | Optional | `false` | Makes the component look like our legacy designs. |

<br>
## Slots
Slot name | Description
| --- | --- |
| default | Content that shows and hides when the user interacts with the header/trigger.
| `header` | Content that will appear in the main header of the "panel". This content will always show.
<br>
## Usage examples

### Basic
``` html
<smile-collapse>
	<template #header>
		This content will render in the "header" that is always showing.
	</template>

	This content will render in the body that hides / shows when a user interacts with the header trigger.
</smile-collapse>
```
<br>
### Using robust custom content

``` html
<smile-collapse removeContainer>
	<template #header>
		<div class="columns is-mobile">
          <div class="column is-4-touch is-2-desktop">
            <span>05/28/2021</span>
          </div>
          <div class="column is-8-touch is-4-desktop">
            <span>Leslie Knope</span>
          </div>
          <div class="column is-6-desktop is-hidden-touch">
            <span>Nightime Clear Aligners</span>
          </div>
        </div>
	</template>

	<div class="columns pt-3">
		<div class="column">
			<p>Some example content</p>
		</div>
		<div class="column">
			<p>Some example content</p>
		</div>
	</div>
</smile-collapse>
```
<br>
## Legacy Props
Below are some props that were created in the first iteration of the component that we do not advise using for future work, but they do still exist. We suggest you utilize your own custom templating in the `#header` slot instead of using the props listed below.

Prop | Type | Description
| --- | --- | --- |
| `primaryTitleText` | String | (optional) Sets the title of the collapse panel. This title is always visible. |
| `secondaryTitleText` | String | (optional) secondary title that can be sgtyled separately from the primary title. |
| `titleTag` | String | (optional) Sets the tag of the title to be either a p tag or a heading tag. |
| `primaryTitleTextCustomClass` | String | (optional) classes to be applied to `primaryTitleText`. |
| `secondaryTitleTextCustomClass` | String | (optional) classes to be applied to `secondaryTitleText`. |
