/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';
import { withKnobs, text, select, boolean } from '@storybook/addon-knobs';

import SmileComparisonTable from './smile-comparison-table.vue';
import SmileComparisonTableColumn from './smile-comparison-table-column.vue';
import componentDocs from './smile-comparison-table.md';

storiesOf('Vue Components / SmileComparisonTable', module)
  .addDecorator(withKnobs)
  .addParameters({ notes: { componentDocs } })
  .add(
    'Smile Comparison Table',
    () => ({
      components: { SmileComparisonTable, SmileComparisonTableColumn },
      props: {
        tableData: {
          type: Array,
          default: [
            {
              id: 1,
              bold: 'Cost',
              highlight: '$1895 or $85/month',
              plain: '$5,000',
            },
            {
              id: 2,
              bold: 'Treatment time',
              highlight: '6-10 months',
              plain: '$5,000',
            },
            {
              id: 3,
              bold: 'Wear time',
              highlight: '1-3 years',
              plain: '$5,000',
            },
            {
              id: 4,
              bold: 'Office visits',
              highlight: 'Not required',
              plain: 'Required',
            },
            {
              id: 5,
              bold: 'Food restrictions',
              highlight: 'None',
              plain: 'Good luck',
            },
            {
              id: 6,
              bold: 'Photos ruined',
              highlight: 'None',
              plain: 'Countless',
            },
            {
              id: 7,
              bold: 'Convenience',
              highlight: 'Removable',
              plain: 'Non-removable',
            },
          ],
        },
        loading: {
          type: Boolean,
          default: boolean('Loading'),
        },
        type: {
          type: String,
          default: select('Theme', ['is-white', 'is-primary'], 'is-white'),
        },
        imageUrl: {
          type: String,
          default: text(
            'Image URL',
            'https://images.ctfassets.net/9bjqpjb3whtl/4aqgp5HH5D5uST5YNEIT8p/91cf4f19fb402aa57fe91a49b862339b/SDC_logo.svg'
          ),
        },
        hasFourColumns: {
          type: Boolean,
          default: boolean('HasFourColumns'),
        },
      },
      computed: {
        boldClasses() {
          return `${this.type} bold has-text-weight-bold cell-divider py-4`;
        },
        highlightClasses() {
          return `${this.type} highlight cell-divider py-4`;
        },
        plainClasses() {
          return `${this.type} plain cell-divider py-4`;
        },
      },
      template: `
          <smile-comparison-table
            :tableData="tableData"
            :loading="loading"
            :hasFourColumns="hasFourColumns"
          >
            <b-table-column
              field="bold"
              label=""
              :headerClass="boldClasses"
              :cellClass="boldClasses"
              v-slot="slotProps"
            >
              {{ slotProps.row.bold }}
            </b-table-column>

            <b-table-column
              field="highlight"
              label=""
              :headerClass="highlightClasses"
              :cellClass="highlightClasses"
              v-slot="slotProps"
            >
              <template #header>
                <img :src="imageUrl">
              </template>
              {{ slotProps.row.highlight }}
            </b-table-column>

            <b-table-column
              field="plain"
              label="Metal Braces"
              :headerClass="plainClasses"
              :cellClass="plainClasses"
              v-slot="slotProps"
            >
              {{ slotProps.row.plain }}
            </b-table-column>
            <b-table-column
              field="plain"
              label="Metal Braces"
              :headerClass="plainClasses"
              :cellClass="plainClasses"
              v-slot="slotProps"
            >
              {{ slotProps.row.plain }}
            </b-table-column>

            </smile-comparison-table>
      `,
    }),
    { info: true }
  );
