import SmileButton from '../smile-button/SmileButton.vue';
import SmileCountrySelector from './smile-country-selector.vue';
import { action } from '@storybook/addon-actions';
import componentDocs from './smile-country-selector.md';
import { boolean, text } from '@storybook/addon-knobs';

export default {
  title: 'Vue Components / SmileCountrySelector',
  parameters: {
    notes: { componentDocs },
  },
};

export const Basic = () => ({
  components: { SmileCountrySelector, SmileButton },
    props: {
    legacyDesign: {
      type: Boolean,
      default: boolean('legacyDesign', false),
    },
    title: {
      type: String,
      default: text('title'),
    },
  },
  data() {
    return {
      countries: [
        {
          name: 'Australia',
          locale: 'en-au',
          country_code_cookie: 'AUSTRALIA',
          region: 'Asia Pacific',
          flag: 'AU',
          language: 'Australian English',
          isContentful: false,
          url: 'https://smiledirectclub.com.au/en-au/?country-chooser-choice=AU',
        },
        {
          name: 'Hong Kong S.A.R. of China',
          locale: 'en-hk',
          country_code_cookie: 'CHINA',
          region: 'Asia Pacific',
          flag: 'HK',
          language: 'Hong Kong English',
          isContentful: false,
          url: 'https://smiledirectclub.com.hk/en-hk/?country-chooser-choice=HK',
        },
        {
          name: 'Hong Kong S.A.R. of China',
          locale: 'zh-hk',
          country_code_cookie: 'CHINA',
          region: 'Asia Pacific',
          flag: 'HK',
          language: '繁體中文',
          isContentful: false,
          url: 'https://smiledirectclub.com.hk/zh-hk/?country-chooser-choice=HK',
        },
        {
          name: 'New Zealand',
          locale: 'en-nz',
          country_code_cookie: 'NEW ZEALAND',
          region: 'Asia Pacific',
          flag: 'NZ',
          language: 'New Zealand English',
          isContentful: false,
          url: 'https://smiledirectclub.co.nz/en-nz/?country-chooser-choice=NZ',
        },
        {
          name: 'Singapore',
          locale: 'en-sg',
          country_code_cookie: 'SINGAPORE',
          region: 'Asia Pacific',
          flag: 'SG',
          language: 'Singapore English',
          isContentful: false,
          url: 'https://smiledirectclub.com.sg/en-sg/?country-chooser-choice=SG',
        },
        {
          name: 'Ireland',
          locale: 'en-ie',
          country_code_cookie: 'IRELAND',
          region: 'Europe',
          flag: 'IE',
          language: 'Irish English',
          isContentful: false,
          url: 'https://smiledirectclub.ie/en-ie/?country-chooser-choice=IE',
        },
        {
          name: 'Netherlands',
          locale: 'nl-nl',
          country_code_cookie: 'NETHERLANDS',
          region: 'Europe',
          flag: 'NL',
          language: 'Nederland Dutch',
          isContentful: false,
          url: 'https://smiledirectclub.nl/nl-nl/?country-chooser-choice=NL',
        },
        {
          name: 'Spain',
          locale: 'es-es',
          country_code_cookie: 'SPAIN',
          region: 'Europe',
          flag: 'ES',
          language: 'Español de España',
          isContentful: false,
          url: 'https://smiledirectclub.es/es-es/?country-chooser-choice=ES',
        },
        {
          name: 'United Kingdom',
          locale: 'en-gb',
          country_code_cookie: 'UNITED KINGDOM',
          region: 'Europe',
          flag: 'GB',
          language: 'British English',
          isContentful: false,
          url: 'https://smiledirectclub.co.uk/en-gb/?country-chooser-choice=GB',
        },
        {
          name: 'France',
          locale: 'fr',
          country_code_cookie: 'FRANCE',
          region: 'Europe',
          flag: 'FR',
          language: 'French',
          isContentful: false,
          url: 'https://smiledirectclub.eu/fr-fr/',
        },
        {
          name: 'Canada',
          locale: 'en-ca',
          country_code_cookie: 'CANADA',
          region: 'North America',
          flag: 'CA',
          language: 'Canadian English',
          isContentful: false,
          url: 'https://smiledirectclub.ca/en-ca/?country-chooser-choice=CA',
        },
        {
          name: 'Canada',
          locale: 'fr-ca',
          country_code_cookie: 'CANADA',
          region: 'North America',
          flag: 'CA',
          language: 'Français canadien',
          isContentful: false,
          url: 'https://smiledirectclub.ca/fr-ca/?country-chooser-choice=CA',
        },
        {
          name: 'Mexico',
          locale: 'es-mx',
          country_code_cookie: 'MEXICO',
          region: 'North America',
          flag: 'MX',
          language: 'Español de Mexico',
          isContentful: false,
          url: 'https://smiledirectclub.com.mx/es-mx/?country-chooser-choice=MX',
        },
        {
          name: 'United States',
          locale: 'en-us',
          country_code_cookie: 'USA',
          region: 'North America',
          flag: 'US',
          language: 'English',
          isContentful: true,
          url: '/?country-chooser-choice=US',
        },
        {
          name: 'United States',
          locale: 'es-us',
          country_code_cookie: 'USA',
          region: 'North America',
          flag: 'US',
          language: 'Español americano',
          isContentful: false,
          url: 'https://smiledirectclub.com/es-us/?country-chooser-choice=US',
        },
      ],
      show: false
    };
  },
  methods: {
    onClick() {
      this.show = true;
    },
    closeSelector() {
      this.show = false;
    },
    countryChange: action('clicked, country change')
  },
  template: `
    <div>
      <smile-button :onClick="onClick" expanded buttonText="Click me"></smile-button>
      <smile-country-selector
        :show="show"
        :countries="countries"
        :legacy-design="legacyDesign"
        :title="title"
        @close="closeSelector"
        @countryChange="countryChange"
      />
    </div>
  `,
});
