/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';

import {
  withKnobs,
  select,
  boolean,
  text,
} from '@storybook/addon-knobs';

import SmileDialog from './smile-dialog.vue';
import SmileButton from '../smile-button/SmileButton.vue';

storiesOf('Vue Components / SmileDialog', module)

  .addDecorator(withKnobs)
  .add('Smile Dialog component', () => ({
    components: { SmileDialog, SmileButton },
    props: {
      message: {
        type: String,
        default: text('message', 'Example message'),
      },
      type: {
        type: String,
        default: select('Type', ['is-primary', 'is-white', 'is-text', 'is-black', 'is-light', 'is-dark', 'is-info', 'is-success', 'is-warning', 'is-danger'], 'is-primary'),
      },
      title: {
        type: String,
        default: text('title', 'Example title'),
      },
      confirmText: {
        type: String,
        default: text('confirmText', 'OK'),
      },
      cancelText: {
        type: String,
        default: text('cancelText', 'Cancel'),
      },
      hasIcon: {
        type: Boolean,
        default: boolean('hasIcon', true),
      },
      icon: {
        type: String,
        default: text('icon', 'x-circle'),
      },
      dialogType: {
        type: String,
        default: select('dialogType', ['alert', 'confirmation']),
      },
    },
    data() {
      return {
        visible: false,
      };
    },
    methods: {
      clicked() {
        this.visible = true;
      },
      confirmed() {
        this.visible = false;
      },
      canceled() {
        this.visible = false;
      },
    },
    template: `
          <div>
            <smile-dialog
              :visible="visible"
              :message="message"
              :title="title"
              :confirmText="confirmText"
              :cancelText="cancelText"
              :type="type"
              :hasIcon="hasIcon"
              :icon="icon"
              :dialogType="dialogType"
              @confirmed="confirmed"
              @canceled="canceled"
            >
            </smile-dialog>
            <smile-button
              :onClick="clicked"
              buttonSize="is-medium"
              buttonStyles="is-primary"
              buttonTag="button"
              buttonText="Click me"
            />
          </div>
      `,
  }), { info: true });
