# SmileDropdown

This component is extended from Buefy's `b-dropdown` component. https://buefy.org/documentation/dropdown/

## Available Props

| Prop              | Type           | Required/Optional | Default value     | Description                                                                                                                   |
| ----------------- | -------------- | ----------------- | ----------------- | ----------------------------------------------------------------------------------------------------------------------------- |
| `triggers`        | Array          | Optional          | `['click']`       | Dropdown will be triggered by specified events                                                                                |
| `position`        | String         | Optional          | `is-bottom-right` | Position of the dropdown relative to the trigger                                                                              |
| `disabled`        | Boolean        | Optional          | false             | Disables dropdown                                                                                                             |
| `animation`       | String         | Optional          | `fade`            | How Steps will be displayed for mobile user. `'minimalist', 'compact', 'null'`                                                |
| `inline`          | Boolean        | Optional          | false             | Next and previous buttons below the component. You can use this property if you want to use your own custom navigation items. |
| `mobileModal`     | Boolean        | Optional          | false             | Dropdown content (items) are shown into a modal on mobile                                                                     |
| `expanded`        | Boolean        | Optional          | false             | Dropdown will be expanded (full-width)                                                                                        |
| `ariaRole`        | String         | Optional          | -                 | Role attribute to be passed to list container for better accessibility                                                        |
| `multiple`        | Boolean        | Optional          | false             | Allows multiple selections                                                                                                    |
| `trapFocus`       | Boolean        | Optional          | true              | Trap focus inside the dropdown.                                                                                               |
| `canClose`        | Boolean, Array | Optional          | true              | Can close dropdown by pressing escape or by clicking outside                                                                  |
| `closeOnClick`    | Boolean        | Optional          | true              | Close dropdown when content is clicked                                                                                        |
| `scrollable`      | Boolean        | Optional          | false             | Dropdown content will be scrollable                                                                                           |
| `maxHeight`       | String, Number | Optional          | `200px`           | Max height of dropdown content                                                                                                |
| `triggerTabindex` | Number         | Optional          | `0`               | Set the tabindex attribute on the dropdown trigger div                                                                        |

## Available events

| Event name      | Description                                                             |
| --------------- | ----------------------------------------------------------------------- |
| `change`        | Triggers when an item is selected                                       |
| `active-change` | Triggers when dropdown is activated or deactivated (visibility of list) |

# SmileDropdownItem

This component is extended from Buefy's `b-dropdown-item` component.

## Available Props

| Prop          | Type    | Required/Optional | Default value | Description                                                        |
| ------------- | ------- | ----------------- | ------------- | ------------------------------------------------------------------ |
| `value`       | Any     | Optional          | null          | The value that will be returned on events and v-model              |
| `separator`   | Boolean | Optional          | false         | Set the item to be a separator                                     |
| `disabled`    | Boolean | Optional          | false         | Item is disabled                                                   |
| `focusable`   | Boolean | Optional          | true          | Item can be focused                                                |
| `custom`      | Boolean | Optional          | false         | Item is not a clickable item                                       |
| `hasLink`     | Boolean | Optional          | false         | Use it if your item is an anchor tag or router-link                |
| `paddingless` | Boolean | Optional          | false         | Remove padding                                                     |
| `ariaRole`    | String  | Optional          | -             | Role attribute to be passed to list item for better accessibility. |

## Available events

| Event name | Description                       |
| ---------- | --------------------------------- |
| `click`    | Triggers when the item is clicked |

## Basic Usage

```html
<smile-dropdown v-model="selectedOptions">
	<template #trigger="{ active }">
		<smile-button label="Click me!" type="is-primary" />
	</template>
	<smile-dropdown-item>Item 1</smile-dropdown-item>
	<smile-dropdown-item>Item 2</smile-dropdown-item>
	<smile-dropdown-item>Item 3</smile-dropdown-item>
</smile-dropdown>
```
