import { storiesOf } from '@storybook/vue';

import { withKnobs, boolean, number, text, select, array } from '@storybook/addon-knobs';

import SmileDropdown from './smile-dropdown.vue';
import SmileDropdownItem from './smile-dropdown-item.vue';
import SmileButton from '../smile-button/SmileButton.vue';

import componentDocs from './smile-dropdown.md';

storiesOf('Vue Components / SmileDropdown', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'SmileDropdown component',
    () => ({
      components: { SmileDropdown, SmileDropdownItem, SmileButton },
      props: {
        triggers: {
          type: Array,
          default: array('triggers', ['click']),
        },
        position: {
          type: String,
          default: select(
            'position',
            ['is-bottom-right', 'is-top-right', 'is-top-left', 'is-bottom-left'],
            'is-bottom-right'
          ),
        },
        disabled: {
          type: Boolean,
          default: boolean('disabled', false),
        },
        animation: {
          type: String,
          default: text('animation', 'fade'),
        },
        inline: {
          type: Boolean,
          default: boolean('inline', false),
        },
        mobileModal: {
          type: Boolean,
          default: boolean('mobileModal', false),
        },
        expanded: {
          type: Boolean,
          default: boolean('expanded', false),
        },
        ariaRole: {
          type: String,
          default: select('ariaRole', ['list', 'menu', 'dialog'], 'list'),
        },
        multiple: {
          type: Boolean,
          default: boolean('multiple', false),
        },
        trapFocus: {
          type: Boolean,
          default: boolean('trapFocus', true),
        },
        canClose: {
          type: Boolean,
          default: boolean('canClose', true),
        },
        closeOnClick: {
          type: Boolean,
          default: boolean('closeOnClick', true),
        },
        appendToBody: {
          type: Boolean,
          default: boolean('appendToBody', false),
        },
        scrollable: {
          type: Boolean,
          default: boolean('scrollable', false),
        },
        maxHeight: {
          type: String,
          default: text('maxHeight', '200px'),
        },
        triggerTabindex: {
          type: Number,
          default: number('triggerTabindex', 0),
        },
      },
      template: `
        <div>
          <smile-dropdown
            :triggers="triggers"
            :position="position"
            :disabled="disabled"
            :inline="inline"
            :animation="animation"
            :mobileModal="mobileModal"
            :expanded="expanded"
            :aria-role="ariaRole"
            :multiple="multiple"
            :trapFocus="trapFocus"
            :canClose="canClose"
            :closeOnClick="closeOnClick"
            :appendToBody="appendToBody"
            :scrollable="scrollable"
            :maxHeight="maxHeight"
            :triggerTabindex="triggerTabindex"
          >
            <template v-slot:trigger>
              <smile-button :style="{ letterSpacing: '3px' }" :rounded="false" buttonText="ADD TO MY CALENDAR" type="is-primary" />
            </template>
            <smile-dropdown-item value="Google" />
            <smile-dropdown-item value="Apple" />
            <smile-dropdown-item value="Outlook" />
          </smile-dropdown>
        <div>
    `,
    }),
    { info: true }
  );
