/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';

import { withKnobs, boolean, text, select } from '@storybook/addon-knobs';

import SmileButton from '../smile-button/SmileButton.vue';
import SmileField from './smile-field.vue';
import SmileInput from '../smile-input/smile-input.vue';
import SmileSelect from '../smile-select/smile-select.vue';
import SmileCheckbox from '../smile-checkbox/smile-checkbox.vue';
import SmileRadio from '../smile-radio/smile-radio.vue';
import componentDocs from './smile-field.md';

storiesOf('Vue Components / SmileField', module)
  .addParameters({ notes: { componentDocs } })

  .addDecorator(withKnobs)
  .add(
    'Smile Field component with Input',
    () => ({
      components: { SmileField, SmileInput },
      props: {
        label: {
          type: String,
          default: text('Label', 'Select an option'),
        },
        labelFor: {
          type: String,
          default: text('Label for', 'test'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        customClass: {
          type: String,
          default: text('Custom Class', ''),
        },
        message: {
          type: String,
          default: text('Message', 'Something went wrong with this field'),
        },
        helperText: {
          type: String,
          default: text('Helper Text', ''),
        },
        hideLabel: {
          type: Boolean,
          default: boolean('Hide Label Text'),
        },
        showMessage: {
          type: Boolean,
          default: boolean('Show Message', false),
        },
        grouped: {
          type: Boolean,
          default: boolean('Grouped'),
        },
        groupMultiline: {
          type: Boolean,
          default: boolean('Group Multiline'),
        },
        showHelperText: {
          type: Boolean,
          default: boolean('Show Helper text', false),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', false),
        },
        hideErrorIcon: {
          type: Boolean,
          default: boolean('Hide Error Icon', false),
        },
      },
      template: `
      <smile-field
        :label="label"
        :labelFor="labelFor"
        :hideLabel="hideLabel"
        :type="type"
        :custom-class="customClass"
        :message="message"
        :grouped="grouped"
        :group-multiline="groupMultiline"
        :show-message="showMessage"
        :show-helper-text="showHelperText"
        :helperText="helperText"
        :legacy-design="legacyDesign"
      >
        <smile-input :legacy-design="legacyDesign" :hideErrorIcon="hideErrorIcon"/>
        <p class="control">
            <b-button label="First" />
        </p>
        <p class="control">
            <b-button label="Second" />
        </p>
        <p class="control">
            <b-button label="Third" />
        </p>
        <p class="control">
            <b-button label="Fourth" />
        </p>
      </smile-field>
      `,
    }),
    { info: true }
  )
  .add(
    'Smile Field component with Select',
    () => ({
      components: { SmileField, SmileSelect },
      props: {
        label: {
          type: String,
          default: text('Label', 'Select an option'),
        },
        labelFor: {
          type: String,
          default: text('Label for', 'test'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        customClass: {
          type: String,
          default: text('Custom Class', ''),
        },
        message: {
          type: String,
          default: text('Message', 'Something went wrong with this field'),
        },
        helperText: {
          type: String,
          default: text('Helper Text', 'Descriptive helper text'),
        },
        hideLabel: {
          type: Boolean,
          default: boolean('Hide Label Text'),
        },
        showMessage: {
          type: Boolean,
          default: boolean('Show Message', false),
        },
        grouped: {
          type: Boolean,
          default: boolean('Grouped'),
        },
        groupMultiline: {
          type: Boolean,
          default: boolean('Group Multiline'),
        },
        showHelperText: {
          type: Boolean,
          default: boolean('Show Helper text', false),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', false),
        },
      },
      data() {
        return {
          options: [
            {
              key: 'OPT1',
              value: 'Option 1',
            },
            {
              key: 'OPT2',
              value: 'Option 2',
            },
            {
              key: 'OPT3',
              value: 'Option 3',
            },
            {
              key: 'OPT4',
              value: 'Option 4',
            },
          ],
          multiple: false,
          size: 'is-small',
        };
      },
      template: `
      <smile-field
        :label="label"
        :labelFor="labelFor"
        :hideLabel="hideLabel"
        :type="type"
        :custom-class="customClass"
        :message="message"
        :grouped="grouped"
        :group-multiline="groupMultiline"
        :show-message="showMessage"
        :show-helper-text="showHelperText"
        :helperText="helperText"
        :legacy-design="legacyDesign"
      >
        <smile-select
          size="is-large"
          :expanded="true"
          :options="options"
          :legacy-design="legacyDesign"
        />
        <p class="control">
          <b-button label="First" />
        </p>
        <p class="control">
            <b-button label="Second" />
        </p>
        <p class="control">
            <b-button label="Third" />
        </p>
        <p class="control">
            <b-button label="Fourth" />
        </p>
      </smile-field>
      `,
    }),
    { info: true }
  )
  .add(
    'Smile Field component with Checkbox',
    () => ({
      components: { SmileField, SmileCheckbox },
      props: {
        label: {
          type: String,
          default: text('Label', 'Select an option'),
        },
        labelFor: {
          type: String,
          default: text('Label for', 'test'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        customClass: {
          type: String,
          default: text('Custom Class', ''),
        },
        message: {
          type: String,
          default: text('Message', 'Something went wrong with this field'),
        },
        helperText: {
          type: String,
          default: text('Helper Text', 'Descriptive helper text'),
        },
        hideLabel: {
          type: Boolean,
          default: boolean('Hide Label Text'),
        },
        showMessage: {
          type: Boolean,
          default: boolean('Show Message', false),
        },
        grouped: {
          type: Boolean,
          default: boolean('Grouped'),
        },
        groupMultiline: {
          type: Boolean,
          default: boolean('Group Multiline'),
        },
        showHelperText: {
          type: Boolean,
          default: boolean('Show Helper text', false),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', false),
        },
      },
      data() {
        return {
          checkboxCustom: 'true',
        };
      },
      template: `
      <smile-field
        :label="label"
        :labelFor="labelFor"
        :hideLabel="hideLabel"
        :type="type"
        :custom-class="customClass"
        :message="message"
        :grouped="grouped"
        :group-multiline="groupMultiline"
        :show-message="showMessage"
        :show-helper-text="showHelperText"
        :helperText="helperText"
        :legacy-design="legacyDesign"
      >
        <smile-checkbox
          v-model="checkboxCustom"
          :true-value="true"
          :false-value="false"
          :legacy-design="legacyDesign"
        >
          {{checkboxCustom}}
        </smile-checkbox>
      </smile-field>
      `,
    }),
    { info: true }
  )
  .add(
    'Smile Field component with Radio',
    () => ({
      components: { SmileField, SmileRadio },
      props: {
        label: {
          type: String,
          default: text('label', 'Select an Option'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        customClass: {
          type: String,
          default: text('Custom Class', ''),
        },
        message: {
          type: String,
          default: text('Message', 'Something went wrong with this field'),
        },
        helperText: {
          type: String,
          default: text('Helper Text', 'Descriptive helper text'),
        },
        hideLabel: {
          type: Boolean,
          default: boolean('Hide Label Text'),
        },
        showMessage: {
          type: Boolean,
          default: boolean('Show Message', false),
        },
        grouped: {
          type: Boolean,
          default: boolean('Grouped'),
        },
        groupMultiline: {
          type: Boolean,
          default: boolean('Group Multiline'),
        },
        showHelperText: {
          type: Boolean,
          default: boolean('Show Helper text', false),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', false),
        },
      },
      data() {
        return {
          radio: 'default',
        };
      },
      template: `
      <smile-field
        :label="label"
        :label-for="radio"
        :hideLabel="hideLabel"
        :type="type"
        :custom-class="customClass"
        :message="message"
        :grouped="grouped"
        :group-multiline="groupMultiline"
        :show-message="showMessage"
        :show-helper-text="showHelperText"
        :helperText="helperText"
        :legacy-design="legacyDesign"
      >
        <smile-radio
          name="radio-group-name"
          v-model="radio"
          native-value="default"
          :legacy-design="legacyDesign"
        >
          Default
        </smile-radio>

        <smile-radio
          name="radio-group-name"
          v-model="radio"
          native-value="info"
          :legacy-design="legacyDesign"
        >
          Info
        </smile-radio>
        <smile-radio
          name="radio-group-name"
          v-model="radio"
          native-value="success"
          :legacy-design="legacyDesign"
        >
          Success
        </smile-radio>
      </smile-field>
    `,
    }),
    { info: true }
  )
  .add(
    'Smile Field component with legacy design',
    () => ({
      components: { SmileButton, SmileField, SmileInput, SmileSelect },
      props: {
        label: {
          type: String,
          default: text('label', 'Select an Option'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        customClass: {
          type: String,
          default: text('Custom Class', ''),
        },
        message: {
          type: String,
          default: text('Message', 'Something went wrong with this field'),
        },
        helperText: {
          type: String,
          default: text('Helper Text', 'Descriptive helper text'),
        },
        hideLabel: {
          type: Boolean,
          default: boolean('Hide Label Text'),
        },
        showMessage: {
          type: Boolean,
          default: boolean('Show Message', false),
        },
        grouped: {
          type: Boolean,
          default: boolean('Grouped'),
        },
        groupMultiline: {
          type: Boolean,
          default: boolean('Group Multiline'),
        },
        showHelperText: {
          type: Boolean,
          default: boolean('Show Helper text', false),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', true),
        },
      },
      data() {
        return {
          options: [
            {
              key: 'OPT1',
              value: 'Option 1',
            },
            {
              key: 'OPT2',
              value: 'Option 2',
            },
            {
              key: 'OPT3',
              value: 'Option 3',
            },
            {
              key: 'OPT4',
              value: 'Option 4',
            },
          ],
          multiple: false,
          size: 'is-small',
        };
      },
      mounted() {
        console.log('this.legacyDesign', this.legacyDesign);
        if (!this.legacyDesign) {
          this.legacyDesign = true;
        }
      },
      template: `
      <smile-field
        :label="label"
        :labelFor="labelFor"
        :hideLabel="hideLabel"
        :type="type"
        :custom-class="customClass"
        :message="message"
        :grouped="grouped"
        :group-multiline="groupMultiline"
        :show-message="showMessage"
        :show-helper-text="showHelperText"
        :helperText="helperText"
        :legacy-design="legacyDesign"
      >
        <smile-input :legacy-design="legacyDesign"/>
        <smile-select
          size="is-large"
          :expanded="true"
          :options="options"
          :legacy-design="legacyDesign"
        />
        <p class="control">
          <smile-button
            :legacy-design="legacyDesign"
            outlined
          >
            First
          </smile-button>
        </p>
        <p class="control">
          <smile-button
            :legacy-design="legacyDesign"
            outlined
          >
            Second
          </smile-button>
        </p>
      </smile-field>
      `,
    }),
    { info: true }
  );
