/* eslint-disable import/no-extraneous-dependencies */
import {
  withKnobs, text,
} from '@storybook/addon-knobs';
import componentDocs from './smile-hero.md';
import SmileHero from './smile-hero.vue';

export default {
  title: 'Vue Components / SmileHero',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const Basic = () => ({
  components: { SmileHero },
  props: {
    title: {
      type: String,
      default: text('title', 'Example title'),
    },
    imageSrc: {
      type: String,
      default: text('imageSrc', 'https://s3-us-west-1.amazonaws.com/media.smiledirectclub.com/p/filer_public/99/85/99853dbb-fbfc-4fba-9000-1888288d56ac/smileshops_smile-guide-with-face-shield.png'),
    },
    imageAlt: {
      type: String,
      default: text('imageAlt', 'SDC patient'),
    },
  },
  template: `
    <smile-hero
      :title="title"
      :imageSrc="imageSrc"
      :imageAlt="imageAlt"
    >
      <template>
        <div class="has-text-black">
          <p>It's your first step to getting a smile you'll love. During your visit, a SmileGuide will take a 3D image of your current smile so you can see what your new smile will look like. And the best part is you only have to go once.</p>
          <br />
          <p> We ensure Smile Shops maintain all the required sanitizing, cleaning and hygienic measures before each appointment. Learn More.</p>
          <br />
          <p>If you still want to start from home, order an impression kit.</p>
        </div>
      </template>
    </smile-hero>
    `,
});


export const withComplexHTMLContent = () => ({
  components: { SmileHero },
  props: {
    title: {
      type: String,
      default: text('title', 'Example title'),
    },
    imageSrc: {
      type: String,
      default: text('imageSrc', 'https://s3-us-west-1.amazonaws.com/media.smiledirectclub.com/p/filer_public/99/85/99853dbb-fbfc-4fba-9000-1888288d56ac/smileshops_smile-guide-with-face-shield.png'),
    },
    imageAlt: {
      type: String,
      default: text('imageAlt', 'SDC patient'),
    },
    content: {
      type: String,
      default: text('content',
        `<div class="has-text-black">
        <p>It's your first step to getting a smile you'll love. During your visit, a SmileGuide will take a 3D image of your current smile so you can see what your new smile will look like. And the best part is you only have to go once.</p>
        <br />
        <p> We ensure Smile Shops maintain all the required sanitizing, cleaning and hygienic measures before each appointment. Learn More.</p>
        <br />
        <p>If you still want to start from home, order an impression kit.</p>
      </div>`
      )
    }
  },
  template: `
    <smile-hero
      :title="title"
      :imageSrc="imageSrc"
      :imageAlt="imageAlt"
    >
      <template>
        <div v-html="content">
      </template>
    </smile-hero>
    `,
});

