/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { action } from '@storybook/addon-actions';
import {
  withKnobs, array, boolean, text, select,
} from '@storybook/addon-knobs';

import SmileHorizontalSlider from './smile-horizontal-slider.vue';
import componentDocs from './smile-horizontal-slider.md';
import SmileImage from '../smile-image/smile-image.vue';

storiesOf('Vue Components / SmileHorizontalSlider', module)
  .addDecorator(withKnobs)
  .addParameters({ notes: { componentDocs } })
  .add(
    'Horizontal Slider with content prop',
    () => ({
      components: { SmileHorizontalSlider, SmileImage },
      props: {
        content: {
          default: select('content type', ['image', 'cards'], 'image'),
          type: String,
        },
        addScrollSnap: {
          default: boolean('addScrollSnap', true),
          type: Boolean,
        },
        addArrows: {
          default: boolean('addArrows', false),
          type: Boolean,
        },
        addScrollbar: {
          default: boolean('addScrollbar', false),
          type: Boolean,
        },
        addSmoothScroll: {
          default: boolean('addSmoothScroll', false),
          type: Boolean,
        },
      },
      data() {
        return {
          src: 'https://via.placeholder.com/300x200',
          alt: 'Visit the dentist',
        };
      },
      template: `
      <smile-horizontal-slider
        :addScrollSnap="addScrollSnap"
        :addArrows="addArrows"
        :addScrollbar="addScrollbar"
        :addSmoothScroll="addSmoothScroll"
      >
        <div v-if="content === 'image'" v-for="(card, index) in 10" :key="index">
          <div class="card" style="margin: 20px; width: 300px; display: block;" >
            <smile-image :src="src" :alt="alt" />
          </div>
        </div>
        <div v-else-if="content === 'cards'" v-for="(card, index) in 10" :key="index">
          <div class="card" style="margin: 20px; width: 300px; display: block;">
            <div class="card-image">
              <smile-image :src="src" :alt="alt" />
            </div>
            <div class="card-content">
              <div class="content">
                Our teeth whitening kit contains everything you’ll need to achieve full enbrightenment.
                <br />
                <time datetime="2016-1-1">11:09 PM - 1 Jan 2016</time>
              </div>
            </div>
          </div>
        </div>
      </smile-horizontal-slider>`,
    }),
    { info: true },
  )
  .add('Horizontal slider with cards', () => ({
    components: { SmileHorizontalSlider, SmileImage },
    props: {
      addScrollSnap: {
        default: boolean('addScrollSnap', true),
        type: Boolean,
      },
      addArrows: {
        default: boolean('addArrows', false),
        type: Boolean,
      },
      addScrollbar: {
        default: boolean('addScrollbar', false),
        type: Boolean,
      },
      addSmoothScroll: {
        default: boolean('addSmoothScroll', false),
        type: Boolean,
      },
    },
    data() {
      return {
        src: 'https://via.placeholder.com/300x200',
        alt: 'Visit the dentist',
      };
    },
    template: `
      <smile-horizontal-slider
        :addArrows="addArrows"
        :addScrollbar="addScrollbar"
        :addScrollSnap="addScrollSnap"
        :addSmoothScroll="addSmoothScroll"
      >
        <div v-for="(card, index) in 10" :key="index">
          <div class="card" style="margin: 20px; width: 300px; display: block;">
            <div class="card-image">
              <smile-image :src="src" :alt="alt" />
            </div>
            <div class="card-content">
              <div class="content">
                Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus nec iaculis mauris. <a>@bulmaio</a>.
                <a href="#">#css</a> <a href="#">#responsive</a>
                <br />
                <time datetime="2016-1-1">11:09 PM - 1 Jan 2016</time>
              </div>
            </div>
          </div>
        </div>
      </smile-horizontal-slider>`,
  }))
  .add('Horizontal slider with images', () => ({
    components: { SmileHorizontalSlider, SmileImage },
    props: {
      addScrollSnap: {
        default: boolean('addScrollSnap', true),
        type: Boolean,
      },
      addArrows: {
        default: boolean('addArrows', false),
        type: Boolean,
      },
      addScrollbar: {
        default: boolean('addScrollbar', false),
        type: Boolean,
      },
      addSmoothScroll: {
        default: boolean('addSmoothScroll', false),
        type: Boolean,
      },
    },
    data() {
      return {
        src: 'https://via.placeholder.com/300x200',
        alt: 'Visit the dentist',
      };
    },
    template: `
      <smile-horizontal-slider
        :addArrows="addArrows"
        :addScrollbar="addScrollbar"
        :addScrollSnap="addScrollSnap"
        :addSmoothScroll="addSmoothScroll"
      >
        <div v-for="(card, index) in 10" :key="index">
          <div class="card" style="margin: 20px; width: 300px; display: block;">
            <smile-image :src="src" :alt="alt" />
          </div>
        </div>
      </smile-horizontal-slider>`,
  }))
  .add('Horizontal slider with cards and link', () => ({
    components: { SmileHorizontalSlider, SmileImage },
    props: {
      addScrollSnap: {
        default: boolean('addScrollSnap', true),
        type: Boolean,
      },
      addArrows: {
        default: boolean('addArrows', false),
        type: Boolean,
      },
      addScrollbar: {
        default: boolean('addScrollbar', false),
        type: Boolean,
      },
      addSmoothScroll: {
        default: boolean('addSmoothScroll', false),
        type: Boolean,
      },
    },
    methods: {
      onClick: action('clicked, custom method would run here...'),
    },
    data() {
      return {
        src: 'https://via.placeholder.com/300x200',
        alt: 'Visit the dentist',
      };
    },
    template: `
      <smile-horizontal-slider
        :addArrows="addArrows"
        :addScrollbar="addScrollbar"
        :addScrollSnap="addScrollSnap"
        :addSmoothScroll="addSmoothScroll"
      >
        <div v-for="(card, index) in 10" :key="index">
          <a @click="onClick" class="card" style="margin: 20px; width: 300px; display: block;">
            <div>
              <div class="card-image">
                <smile-image :src="src" :alt="alt" />
              </div>
              <div class="card-content">
                <div class="content">
                  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus nec iaculis mauris. <a>@bulmaio</a>.
                  <a href="#">#css</a> <a href="#">#responsive</a>
                  <br />
                  <time datetime="2016-1-1">11:09 PM - 1 Jan 2016</time>
                </div>
              </div>
            </div>
          </a>
        </div>
      </smile-horizontal-slider>`,
  }))
  .add('Horizontal slider with images and link', () => ({
    components: { SmileHorizontalSlider, SmileImage },
    props: {
      addScrollSnap: {
        default: boolean('addScrollSnap', true),
        type: Boolean,
      },
      addArrows: {
        default: boolean('addArrows', false),
        type: Boolean,
      },
      addScrollbar: {
        default: boolean('addScrollbar', false),
        type: Boolean,
      },
      addSmoothScroll: {
        default: boolean('addSmoothScroll', false),
        type: Boolean,
      },
    },
    methods: {
      onClick: action('clicked, custom method would run here...'),
    },
    data() {
      return {
        src: 'https://via.placeholder.com/300x200',
        alt: 'Visit the dentist',
      };
    },
    template: `
      <smile-horizontal-slider
        :addArrows="addArrows"
        :addScrollbar="addScrollbar"
        :addScrollSnap="addScrollSnap"
        :addSmoothScroll="addSmoothScroll"
      >
        <div v-for="(card, index) in 10" :key="index">
          <a @click="onClick" class="card" style="margin: 20px; width: 300px; display: block;">
            <div>
                <smile-image :src="src" :alt="alt" />
            </div>
          </a>
        </div>
      </smile-horizontal-slider>`,
  }))
  .add('Items with drop shadow', () => ({
    components: { SmileHorizontalSlider, SmileImage },
    props: {
      addScrollSnap: {
        default: boolean('addScrollSnap', false),
        type: Boolean,
      },
      addArrows: {
        default: boolean('addArrows', false),
        type: Boolean,
      },
      addScrollbar: {
        default: boolean('addScrollbar', false),
        type: Boolean,
      },
      addSmoothScroll: {
        default: boolean('addSmoothScroll', false),
        type: Boolean,
      },
    },
    methods: {
      onClick: action('clicked, custom method would run here...'),
    },
    data() {
      return {
        src: 'https://via.placeholder.com/300x200',
        alt: 'Visit the dentist',
      };
    },
    template: `
    <div>
      <smile-horizontal-slider
        :addArrows="addArrows"
        :addScrollbar="addScrollbar"
        :addScrollSnap="addScrollSnap"
        :addSmoothScroll="addSmoothScroll"
      >
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 1</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 2</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 3</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 4</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 5</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 6</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 7</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 8</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 9</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 10</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 11</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 12</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 13</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 14</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 15</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 16</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 17</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 18</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 19</div>
        <div class="is-flex is-justify-content-center is-align-items-center p-10" style="box-shadow: 0px 12px 20px 0px rgb(0 0 0 / 8%) !important;">Item 20</div>
      </smile-horizontal-slider>
      </div>`,
  }));
