# Smile Input

The `<smile-input>` component is extended from the `<b-input>` component in Buefy: https://buefy.org/documentation/input, and customized for our Design System. This component handles just the input element, and you can use `<smile-field>` as a wrapper to handle the input label, helper text, etc.

## Available props

| Prop                   | Type           | Required? | Default value | Description                                                                                                                                                                                                               |
| ---------------------- | -------------- | --------- | ------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `legacy-design`        | Boolean        | []        | `false`       | Adds a class to make the component look like our legacy designs.                                                                                                                                                          |
| `v-model`              | String, Number | --        | --            | Binding value                                                                                                                                                                                                             |
| `lazy`                 | Boolean        | []        | `false`       | Makes the binding lazy. Note: `v-model.lazy` won't work                                                                                                                                                                   |
| `type`                 | String         | []        | `text`        | Any native HTML input type, and `textarea`                                                                                                                                                                                |
| `size`                 | String         | []        | --            | Vertical size of input. Options include: `is-small`, `is-medium`, `is-large`                                                                                                                                              |
| `expanded`             | Boolean        | []        | `false`       | Makes input full width when inside a grouped or addon field                                                                                                                                                               |
| `password-reveal`      | Boolean        | []        | `false`       | Add the reveal password functionality                                                                                                                                                                                     |
| `loading`              | Boolean        | []        | `false`       | Displays input in loading state                                                                                                                                                                                           |
| `icon`                 | String         | []        | `false`       | Icon name: will display on the left side of the input                                                                                                                                                                     |
| `icon-right`           | String         | []        | `false`       | Icon name: will display on the right side of the input                                                                                                                                                                    |
| `icon-clickable`       | Boolean        | []        | `false`       | Make the icon on the left clickable                                                                                                                                                                                       |
| `icon-right-clickable` | Boolean        | []        | `false`       | Make the icon on the right clickable                                                                                                                                                                                      |
| `maxlength`            | String, Number | []        | --            | Same as native HTML `maxlength`, plus character counter                                                                                                                                                                   |
| `has-counter`          | Boolean        | []        | `false`       | Show character counter when `maxlength` prop is passed counter                                                                                                                                                            |
| `custom-class`         | String         | []        | --            | CSS classes to be applied to input element                                                                                                                                                                                |
| `validation-message`   | String         | []        | --            | The message which is shown when a validation error occurs                                                                                                                                                                 |
| `hideErrorIcon`        | Boolean        | []        | false         | Determines whether or not to show the icon right when there is an error present. NOTE: the icon only shows when the smile-input and the smile-field are used in tandem. The smile field must have the type of `is-danger` |

## Events

| Event name        | Description                                                                              |
| ----------------- | ---------------------------------------------------------------------------------------- |
| `@iconRightClick` | Fired when clicking on the icon right, provided `icon-right-clickable` is set to `true`. |

## Usage examples

### Basic

```html
<smile-input v-model="inputModel" id="your-unique-id" />
```

### With SmileField

```html
<smile-field label="input label here" message="helper text here">
	<smile-input v-model="inputModel" id="your-unique-id" type="textarea" />
</smile-field>
```
