/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';

import { action } from '@storybook/addon-actions';
import { withKnobs, boolean, text, select } from '@storybook/addon-knobs';

import SmileInput from './smile-input.vue';
import SmileField from '../smile-field/smile-field.vue';
import componentDocs from './smile-input.md';

storiesOf('Vue Components / SmileInput', module)
  .addParameters({ notes: { componentDocs } })

  .addDecorator(withKnobs)
  .add(
    'SmileInput',
    () => ({
      components: { SmileInput },
      props: {
        id: {
          type: String,
          default: text('id', 'your-unique-id'),
        },
        lazy: {
          type: Boolean,
          default: boolean('lazy'),
        },
        type: {
          type: String,
          default: text('type', ''),
        },
        size: {
          type: String,
          default: select('size', ['', 'is-small', 'is-medium', 'is-large'], null),
        },
        expanded: {
          type: Boolean,
          default: boolean('expanded'),
        },
        passwordReveal: {
          type: Boolean,
          default: boolean('password-reveal'),
        },
        loading: {
          type: Boolean,
          default: boolean('loading'),
        },
        icon: {
          type: String,
          default: text('icon', ''),
        },
        iconRight: {
          type: String,
          default: text('icon-right', ''),
        },
        iconClickable: {
          type: Boolean,
          default: boolean('icon-clickable'),
        },
        iconRightClickable: {
          type: Boolean,
          default: boolean('icon-right-clickable'),
        },
        maxlength: {
          type: [String, Number],
          default: text('maxlength', ''),
        },
        hasCounter: {
          type: Boolean,
          default: boolean('has-counter'),
        },
        customClass: {
          type: String,
          default: text('custom-class', ''),
        },
        validationMessage: {
          type: String,
          default: text('validation-message', ''),
        },
        alertOnBlurEvent: {
          type: Boolean,
          default: boolean('alert-on-blur-event', false),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', false),
        },
        hideErrorIcon: {
          type: Boolean,
          default: boolean('hideErrorIcon', false),
        },
      },
      data() {
        return {
          inputModel: '',
        };
      },
      methods: {
        onBlur() {
          if (this.alertOnBlurEvent) {
            alert('Input field was Blurred');
          }
          return 1;
        },
        action: action('Option selected'),
      },
      template: `
      <div>
        <smile-input
          v-model="inputModel"
          :id="id"
          :lazy="lazy"
          :type="type"
          :size="size"
          :expanded="expanded"
          :password-reveal="passwordReveal"
          :loading="loading"
          :icon="icon"
          :icon-right="iconRight"
          :icon-clickable="iconClickable"
          :icon-right-clickable="iconRightClickable"
          :maxlength="maxlength"
          :has-counter="hasCounter"
          :custom-class="customClass"
          :validation-message="validationMessage"
          @blur="onBlur() && action('blur')"
          @focus="action('focus')"
          :legacy-design="legacyDesign"
        />
        <div>V-Model value: {{ inputModel }}</div>
      </div>
      `,
    }),
    { info: true }
  )
  .add(
    'Smile Input With SmileField',
    () => ({
      components: { SmileInput, SmileField },
      props: {
        placeholderText: {
          type: String,
          default: text('Placeholder Text', 'Placeholder'),
        },
        label: {
          type: String,
          default: text('Label', 'Input Label'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        message: {
          type: String,
          default: text('Message', 'Something went wrong with this field'),
        },
        showMessage: {
          type: Boolean,
          default: boolean('Show Message', false),
        },
        showHelperText: {
          type: Boolean,
          default: boolean('Show Helper text', false),
        },
        helperText: {
          type: String,
          default: text('Helper Text', 'Descriptive helper text'),
        },
      },
      template: `
      <div>
      <smile-field
        :label="label"
        :type="type"
        :message="message"
        :show-message="showMessage"
        :show-helper-text="showHelperText"
        :helperText="helperText"
      >
        <smile-input :placeholder="placeholderText"/>
      </smile-field>
      </div>
      `,
    }),
    { info: true }
  );
