# Smile Loading

The `<smile-loading>` component displays a spinner over its container when activated. You may use the `isFullPage` prop if you wish for the loading to display over your entire page/viewport.

You can also use the slot provided to display any custom content instead of the default spinner.

## Available props

Prop | Type | Default value | Description
| --- | --- | --- | --- |
| `loadingMessage` | String | "Loading..." | This is a required prop for accessibility. It is the message that will be announced to screen readers when the loading is active. It is NOT visible at any point by default. |
| `active` | Boolean | `false` | Activates / shows the loader when set to `true`. |
| `isFullPage` | Boolean | `false` | The loader will overlay the entire page / viewport when set to `true`. |
| `canCancel` | Boolean | `false` | Allows users to close the loading with either the escape key or by clicking outside of the loader. |
| `onCancel` | Function | -- | You may provide a function that is fired as a callback when loading is canceled. |


## Usage examples

### Basic
``` html
<smile-loading
	:active="yourBooleanActiveState"
	loadingMessage="insert loading message here for screen readers">
</smile-loading>
```
### Custom "loading" content
Anything you wrap with the loading component will be displayed when the loading is active instead of the default spinner.

``` html
<smile-loading
	:active="yourBooleanActiveState"
	loadingMessage="insert loading message here for screen readers and/or custom content"
	isFullPage
	canCancel
	:on-cancel="yourCustomCallbackFunction">

	<!-- Some custom HTML/loading content -->
	<div class="box p-5 m-5 is-relative has-text-centered has-radius-large has-background-black">
		<img src="https://placekitten.com/200/100" alt="" class="mb-2 is-align-self-center" />
		<p class="has-text-white">{{ loadingMessage }}</p>
	</div>

</smile-loading>
```
