import { withKnobs, text, boolean } from '@storybook/addon-knobs';
import SmileLoading from './smile-loading.vue';
import componentDocs from './smile-loading.md';

export default {
  title: 'Vue Components / SmileLoading',
  decorators: [withKnobs({
    escapeHTML: false,
  })],
  parameters: {
    notes: { componentDocs },
  },
};

export const DefaultSpinner = () => ({
  components: { SmileLoading },
  props: {
    storyLoadingMessage: {
      type: String,
      default: text('loadingMessage', 'Loading message used for screen readers in the aria label'),
    },
    storyActive: {
      type: Boolean,
      default: boolean('active', false),
    },
    storyIsFullPage: {
      type: Boolean,
      default: boolean('isFullPage', false),
    },
    storyCanCancel: {
      type: Boolean,
      default: boolean('canCancel', false),
    },
  },
  methods: {
    storyCallbackFunction() {
      alert("onCancel prop's callback function fired!"); // eslint-disable-line
    },
  },
  template: `
    <div class="container has-background-light p-10">
      <h1 class="title mb-5">A demo page with a smile-loading component in the card</h1>
      <p class="mb-10">Adjust the active and isFullPage knobs to observe how the loader component works. By default the loader stays contained to the component it sits inside.</p>
      <div class="columns">
        <div class="column is-one-third">
          <div class="card p-10">
            <h1 class="title">Card title</h1>
            <p>The loader is inside this card</p>
            <img src="https://placekitten.com/200/100" alt=""/>

            <smile-loading
              :active="storyActive"
              :is-full-page="storyIsFullPage"
              :loading-message="storyLoadingMessage"
              :can-cancel="storyCanCancel"
              :on-cancel="storyCallbackFunction">
            </smile-loading>

          </div>
        </div>
      </div>
    </div>
  `,
});

export const CustomSlotContent = () => ({
  components: { SmileLoading },
  props: {
    storyLoadingMessage: {
      type: String,
      default: text('loadingMessage', 'Maybe I want custom loading content...'),
    },
    storyCustomContent: {
      type: String,
      default: text('Custom Content in Slot', '<div class="card p-5">Custom component/content here</div>'),
    },
    storyActive: {
      type: Boolean,
      default: boolean('active', false),
    },
    storyIsFullPage: {
      type: Boolean,
      default: boolean('isFullPage', false),
    },
    storyCanCancel: {
      type: Boolean,
      default: boolean('canCancel', false),
    },
  },
  methods: {
    storyCallbackFunction() {
      alert("onCancel prop's callback function fired!"); // eslint-disable-line
    },
  },
  template: `
    <div class="container has-background-light p-10">
      <h1 class="title mb-5">A demo page with a smile-loading component in the card</h1>
      <p class="mb-10">Adjust the active and isFullPage knobs to observe how the loader component works. By default the loader stays contained to the component it sits inside.</p>
      <div class="columns">
        <div class="column is-one-third">
          <div class="card p-10">
            <h1 class="title">Card title</h1>
            <p class="pb-2">The loader is inside this card with custom loading content.</p>
            <img src="https://placekitten.com/200/100" alt=""/>

            <smile-loading
              :active="storyActive"
              :is-full-page="storyIsFullPage"
              :loading-message="storyLoadingMessage"
              :can-cancel="storyCanCancel"
              :on-cancel="storyCallbackFunction">

              <div v-html="storyCustomContent" />

            </smile-loading>
          </div>
        </div>
      </div>
    </div>
  `,
});
