import { withKnobs, text, boolean } from '@storybook/addon-knobs';

import SmileMediaCard from './smile-media-card.vue';
import SmileVideo from '../smile-video/smile-video.vue';
import componentDocs from './smile-media-card.md';

export default {
  title: 'Vue Components / SmileMediaCard',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const Default = () => ({
  components: { SmileMediaCard },
  props: {
    containerUrl: {
      type: String,
      default: text('Prop: containerUrl', ''),
    },
    imageSrc: {
      type: String,
      default: text('Prop: imageSrc', 'https://via.placeholder.com/300'),
    },
    imageAlt: {
      type: String,
      default: text('Prop: imageAlt', 'Product image'),
    },
    title: {
      type: String,
      default: text('Prop: title', 'Card title here'),
    },
    cardContent: {
      type: String,
      default: text(
        'Slot: card-content',
        `<p>Lorem ipsum dolor sit amet, <a href="https://smiledirectclub.com">consectetur adipiscing elit</a>, sed
        do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>`
      ),
    },
    cardFooter: {
      type: String,
      default: text('Slot: card-footer', `<a href="https://google.com">A link in the footer</a>`),
    },
    hasRoundedImage: {
      type: Boolean,
      default: boolean('Prop: hasRoundedImage', false),
    },
    imageContainerCustomClass: {
      type: String,
      default: text('Prop: imageContainerCustomClass', ''),
    },
    contentContainerCustomClass: {
      type: String,
      default: text('Prop: contentContainerCustomClass', ''),
    },
    footerContainerCustomClass: {
      type: String,
      default: text('Prop: footerContainerCustomClass', ''),
    },
  },
  template: `
      <smile-media-card
        :containerUrl="containerUrl"
        :title="title"
        :imageSrc="imageSrc"
        :imageAlt="imageAlt"
        :hasRoundedImage="hasRoundedImage"
        :imageContainerCustomClass="imageContainerCustomClass"
        :contentContainerCustomClass="contentContainerCustomClass"
        :footerContainerCustomClass="footerContainerCustomClass"
      >
        <template #card-content>
          <div v-html="cardContent"/>
        </template>
        <template #card-footer>
          <div v-html="cardFooter"/>
        </template>
      </smile-media-card>
      `,
});

export const smileMediaCardWithProfileImage = () => ({
  components: { SmileMediaCard },
  props: {
    imageSrc: {
      type: String,
      default: text('Image source', 'https://via.placeholder.com/300'),
    },
    imageAlt: {
      type: String,
      default: text('Image alt', 'Smile Direct Club customer Gabriel smiling before and after treatment'),
    },
    hasRoundedImage: {
      type: Boolean,
      default: boolean('hasRoundedImage', true),
    },
    imageContainerCustomClass: {
      type: String,
      default: text('imageContainerCustomClass', ''),
    },
    contentContainerCustomClass: {
      type: String,
      default: text('contentContainerCustomClass', ''),
    },
  },
  template: `
    <div style="max-width: 400px">
      <smile-media-card
        :imageSrc="imageSrc"
        :imageAlt="imageAlt"
        :hasRoundedImage="hasRoundedImage"
        :imageContainerCustomClass="imageContainerCustomClass"
        :contentContainerCustomClass="contentContainerCustomClass">
        <template v-slot:card-content>
          <figure>
            <blockquote cite="https://www.huxley.net/bnw/four.html" class="mb-2">
                <p class="has-text-black">The fact that my aligners were clear and fast motivated me to change more about my appearance than just my smile, which led me to change my habits and lose 100+ pounds.</p>
            </blockquote>
            <figcaption class="has-text-right">
              <p class="has-text-black has-text-weight-semibold">—Gabriel</p>
              <p class="has-text-grey">#sdctruestory</p>
            </figcaption>
          </figure>
        </template>
      </smile-media-card>
    </div>
    `,
});

export const smileMediaCardWithVideo = () => ({
  components: { SmileMediaCard, SmileVideo },
  props: {
    videoName: {
      type: String,
      required: true,
      default: text(
        'Video Name',
        '//res.cloudinary.com/smiledirectclub/video/upload/vc_auto/v1608657826/live-video.mp4'
      ),
    },
  },
  template: `
    <div style="max-width: 400px">
      <smile-media-card>
        <template v-slot:card-video>
         <smile-video
          :videoName="videoName"
        />
        </template>
        <template v-slot:card-content>
          <figure>
            <blockquote cite="https://www.huxley.net/bnw/four.html" class="mb-2">
                <p class="has-text-black">The fact that my aligners were clear and fast motivated me to change more about my appearance than just my smile, which led me to change my habits and lose 100+ pounds.</p>
            </blockquote>
            <figcaption class="has-text-right">
              <p class="has-text-black has-text-weight-semibold">—Gabriel</p>
              <p class="has-text-grey">#sdctruestory</p>
            </figcaption>
          </figure>
        </template>
      </smile-media-card>
    </div>
    `,
});

export const smileMediaCardWithCustomImageComponent = () => ({
  components: { SmileMediaCard },
  props: {
    imageContainerCustomClass: {
      type: String,
      default: text('imageContainerCustomClass', ''),
    },
    contentContainerCustomClass: {
      type: String,
      default: text('contentContainerCustomClass', ''),
    },
  },
  template: `
    <div style="max-width: 400px">
      <smile-media-card
        :imageSrc="imageSrc"
        :imageAlt="imageAlt"
        :hasRoundedImage="hasRoundedImage"
        :imageContainerCustomClass="imageContainerCustomClass"
        :contentContainerCustomClass="contentContainerCustomClass"
      >
        <template v-slot:card-image>
          <img
            src="https://images.ctfassets.net/9bjqpjb3whtl/4booiFOUh6JAQZT0sdj29b/f73488cb0f0814ab427ad7e483d6dae2/2-women-smiling.jpg?w=320&fm=jpg"
            alt="Image element"
          />
        </template>
        <template v-slot:card-content>
          <figure>
            <blockquote cite="https://www.huxley.net/bnw/four.html" class="mb-2">
                <p class="has-text-black">This media card has a custom image element</p>
            </blockquote>
            <figcaption class="has-text-right">
              <p class="has-text-black has-text-weight-semibold">—Esteban</p>
              <p class="has-text-grey">#sdctruestory</p>
            </figcaption>
          </figure>
        </template>
      </smile-media-card>
    </div>
    `,
});

export const smileMediaCardWithAlternatingWhiteSpace = () => ({
  components: { SmileMediaCard },
  template: `
    <div class='is-flex-direction-row is-flex'>
      <smile-media-card
        style='width: 250px'
        title="Shtuff"
        :imageSrc="imageSrc"
        :imageAlt="imageAlt"
        :hasRoundedImage="hasRoundedImage"
        :imageContainerCustomClass="imageContainerCustomClass"
        :contentContainerCustomClass="contentContainerCustomClass"
        :footerContainerCustomClass="footerContainerCustomClass">
        <template v-slot:card-content>
          <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed
          do eiusmod tempor incididunt ut labore et dolore magna aliqua.
          Ut enim ad minim veniam, quis nostrud exercitation
          ullamco laboris nisi ut aliquip ex ea commodo consequat.
          Duis aute irure dolor in reprehenderit in voluptate velit
          esse cillum dolore eu fugiat nulla pariatur. Excepteur sint
          occaecat cupidatat non proident, sunt in culpa qui officia
          deserunt mollit anim id est laborum.</p>
        </template>
        <template v-slot:card-footer>
          <a href="https://smiledirectclub.com">Shop now</a>
        <template>
      </smile-media-card>

      <smile-media-card
        title="Shtuff"
        style='width: 250px'
        :imageSrc="imageSrc"
        :imageAlt="imageAlt"
        :hasRoundedImage="hasRoundedImage"
        :imageContainerCustomClass="imageContainerCustomClass"
        :contentContainerCustomClass="contentContainerCustomClass"
        :footerContainerCustomClass="footerContainerCustomClass">
        <template v-slot:card-content>
          <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed
          do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p>
        </template>
        <template v-slot:card-footer>
          <a href="https://smiledirectclub.com">Shop now</a>
        <template>
      </smile-media-card>

      <smile-media-card
      style='width: 250px'
      title="Shtuff"
      :imageSrc="imageSrc"
      :imageAlt="imageAlt"
      :hasRoundedImage="hasRoundedImage"
      :imageContainerCustomClass="imageContainerCustomClass"
      :contentContainerCustomClass="contentContainerCustomClass"
      :footerContainerCustomClass="footerContainerCustomClass">
      <template v-slot:card-content>
        <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed
        do eiusmod tempor incididunt ut labore et dolore magna aliqua.
        Ut enim ad minim veniam, quis nostrud exercitation
        ullamco laboris nisi ut aliquip ex ea commodo consequat.
        Duis aute irure dolor in reprehenderit in voluptate velit
        esse cillum dolore eu fugiat nulla pariatur. Excepteur sint
        occaecat cupidatat non proident, sunt in culpa qui officia
        deserunt mollit anim id est laborum.</p>
      </template>
      <template v-slot:card-footer>
        <a href="https://smiledirectclub.com">Shop now</a>
      <template>
    </smile-media-card>

      <div>
      `,
});
