# Smile Message

This component is extended from Buefy's `b-message` component. https://buefy.org/documentation/message.

Use this component when you display some text that should catch the attention of the user. This component accepts html content.

## Available Props

| Prop             | Type    | Required/Optional | Default value  | Description                                                                                                                                                                                                                                          |
| ---------------- | ------- | ----------------- | -------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `value`          | Boolean | Optional          | `true`         | The initial value that will be used to determine whether we show the modal or not. It has a watcher that updates the value of `active`on changes to `value`coming from the parent component. This keeps the computed property `isActive` up to date. |
| `type`           | String  | Optional          | `'is-primary'` | Type (color) of the message. Possible values: `'is-white'`, `'is-black'`, `'is-light'`, `'is-dark'`, `'is-primary'`, `'is-info'`, `'is-success'`, `'is-warning'`, `'is-danger'`                                                                      |
| `title`          | String  | Optional          | `''`           | Message title.                                                                                                                                                                                                                                       |
| `closable`       | Boolean | Optional          | -              | Adds an 'X' button that closes the notification — works if has a `title`.                                                                                                                                                                            |
| `autoClose`      | Boolean | Optional          | -              | Hide notification after `duration`.                                                                                                                                                                                                                  |
| `duration`       | Number  | Optional          | `2000`         | Visibility duration in miliseconds.                                                                                                                                                                                                                  |
| `hasIcon`        | Boolean | Optional          | -              | Adds an icon on the left side depending on the `type` (or the `icon` prop if defined).                                                                                                                                                               |
| `icon`           | String  | Optional          | `''`           | Icon name to use with `has-icon`.                                                                                                                                                                                                                    |
| `size`           | String  | Optional          | `''`           | Size of the control. Possible values: `'is-small'`, '`is-medium'`, `'is-large'`; validator will be falsy if passed any other value.                                                                                                                  |
| `iconSize`       | String  | Optional          | `''`           | Size of the icon. Possible values: `'is-small'`, `'is-medium'`, `'is-large'`.                                                                                                                                                                        |
| `ariaCloseLabel` | String  | Optional          | `''`           | Label for the close button, to be read by accessibility screenreaders..                                                                                                                                                                              |

## Available slots

| Slot name | Description            | Props (if scoped) |
| --------- | ---------------------- | ----------------- |
| `header`  | Message custom header. | -                 |

## Available Events

| Event name | Description                                                                               |
| ---------- | ----------------------------------------------------------------------------------------- |
| `input`    | Emitted on every update of the `isActive` computed property with the new value being set. |

## Basic Usage

```html
<template>
	<smile-message
		v-model="isMessageActive"
		:type="type"
		:title="title"
		:closable="closable"
		:has-icon="hasIcon"
		:icon="icon"
		:size="size"
		:icon-size="iconSize"
		:aria-close-label="ariaCloseLabel"
	>
		<div v-html="content" />
	</smile-message>
</template>

<script>
	export default {
		data() {
			return {
				type: 'is-black',
				title: 'Important message from our sponsor',
				closable: false,
				hasIcon: true,
				icon: 'smile',
				size: 'is-small',
				iconSize: 'is-small',
				ariaCloseLabel: 'Control to close the message',
				isMessageActive: true,
			};
		},
	};
</script>
```
