/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { withKnobs, boolean, text, select, number } from '@storybook/addon-knobs';

import { action } from '@storybook/addon-actions';
import SmileMessage from './smile-message.vue';
import SmileButton from '../smile-button/SmileButton.vue';
import componentDocs from './smile-message.md';

storiesOf('Vue Components / SmileMessage', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(
    withKnobs({
      escapeHTML: false,
    })
  )
  .add(
    'Smile Message',
    () => ({
      components: { SmileMessage, SmileButton },
      props: {
        title: {
          type: String,
          default: text('Title', 'Example message title'),
        },
        closable: {
          type: Boolean,
          default: boolean('Closable', false),
        },
        hasIcon: {
          type: Boolean,
          default: boolean('Has icon', false),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-primary',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            'is-primary'
          ),
        },
        icon: {
          type: String,
          default: text('Icon', 'smile'),
        },
        size: {
          type: String,
          default: select('Size', ['', 'is-small', 'is-medium', 'is-large'], ''),
        },
        iconSize: {
          type: String,
          default: select('Icon size', ['', 'is-small', 'is-medium', 'is-large'], ''),
        },
        ariaCloseLabel: {
          type: String,
          default: text('Close label', 'Close label'),
        },
        content: {
          type: String,
          default: text('Content', 'Content with <b>tags</b>'),
        },
      },
      methods: {
        onFinish: action('hide message'),
      },
      template: `
        <smile-message
          @input="onFinish"
          :type="type"
          :title="title"
          :closable="closable"
          :has-icon="hasIcon"
          :icon="icon"
          :size="size"
          :icon-size="iconSize"
          :aria-close-label="ariaCloseLabel"
        ><div v-html="content" />
        </smile-message>
      `,
    }),
    { info: true }
  )
  .add(
    'Smile Message with header',
    () => ({
      components: { SmileMessage, SmileButton },
      props: {
        title: {
          type: String,
          default: text('Title', 'Example message title'),
        },
        closable: {
          type: Boolean,
          default: boolean('Closable', false),
        },
        hasIcon: {
          type: Boolean,
          default: boolean('Has icon', false),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-primary',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            'is-primary'
          ),
        },
        icon: {
          type: String,
          default: text('Icon', 'smile'),
        },
        size: {
          type: String,
          default: select('Size', ['', 'is-small', 'is-medium', 'is-large'], ''),
        },
        iconSize: {
          type: String,
          default: select('Icon size', ['', 'is-small', 'is-medium', 'is-large'], ''),
        },
        ariaCloseLabel: {
          type: String,
          default: text('Close label', 'Close label'),
        },
        content: {
          type: String,
          default: text('Content', 'Content with <b>tags</b>'),
        },
      },
      methods: {
        onFinish: action('hide message'),
      },
      template: `
        <smile-message
          @input="onFinish"
          :type="type"
          :title="title"
          :closable="closable"
          :has-icon="hasIcon"
          :icon="icon"
          :size="size"
          :icon-size="iconSize"
          :aria-close-label="ariaCloseLabel"
        >
          <slot name="header">
            <h1>The header</h1>
          </slot>

          <div v-html="content" />
        </smile-message>
      `,
    }),
    { info: true }
  )
  .add('Smile Message autoclose', () => ({
    components: { SmileMessage, SmileButton },
    props: {
      title: {
        type: String,
        default: text('Title', 'Title with <b>tags</b>'),
      },
      type: {
        type: String,
        default: select(
          'Type',
          [
            'is-white',
            'is-black',
            'is-light',
            'is-dark',
            'is-primary',
            'is-info',
            'is-success',
            'is-warning',
            'is-danger',
          ],
          'is-primary'
        ),
      },
      closable: {
        type: Boolean,
        default: boolean('Closable', false),
      },
      autoClose: {
        type: Boolean,
        default: boolean('Auto close', true),
      },
      duration: {
        type: Number,
        default: number('Duration', 2000, { range: false, step: 1000 }),
      },
      hasIcon: {
        type: Boolean,
        default: boolean('Has icon', false),
      },
      icon: {
        type: String,
        default: text('Icon', 'smile'),
      },
      size: {
        type: String,
        default: select('Size', ['', 'is-small', 'is-medium', 'is-large'], ''),
      },
      iconSize: {
        type: String,
        default: select('Icon size', ['', 'is-small', 'is-medium', 'is-large'], ''),
      },
      ariaCloseLabel: {
        type: String,
        default: text('Close label', 'Close label'),
      },
      content: {
        type: String,
        default: text('Content', 'Content with <b>tags</b>'),
      },
    },
    data() {
      return {
        show: false,
      };
    },
    methods: {
      onClick() {
        this.show = true;
      },
      onFinish: action('hide message'),
    },
    template: `
        <div>
          <smile-button :onClick="onClick" buttonSize="is-medium" buttonStyles="is-primary" buttonTag="button" buttonText="Click me"/>
          <smile-message
            v-model="show"
            @input="onFinish"
            :type="type"
            :duration="duration"
            :autoClose="autoClose"
            :closable="closable"
            :has-icon="hasIcon"
            :icon="icon"
            :size="size"
            :icon-size="iconSize"
            :aria-close-label="ariaCloseLabel"
          >
            <template #header>
              <div v-html="title"/>
            </template>
            <div v-html="content" />
          </smile-message>
        </div>
      `,
  }));
