# Smile Modal

A robust component for creating a modal.

## Available props

| Prop                     | Type             | Default                  | Description                                                                                                                                                                |
| ------------------------ | ---------------- | ------------------------ | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `isActive`               | Boolean          |                          | Whether modal is active or not, use the .sync modifier to make it two-way binding                                                                                          |
| `hasSecondaryBackground` | Boolean          | false                    | When true, displays the designated secondary background                                                                                                                    |
| `component`              | Object, Function |                          | Component to be injected, used to open a component modal programmatically. Close modal within the component by emitting a 'close' event — this.$emit('close')              |
| `parent`                 | Vue              |                          | Parent component of the modal, required if using component                                                                                                                 |
| `props`                  | Object           |                          | Props to be bound to the injected component                                                                                                                                |
| `events`                 | Object           |                          | Events to be bound to the injected component                                                                                                                               |
| `content`                | String, Array    |                          | HTML content                                                                                                                                                               |
| `width`                  | Number, String   |                          | Width of the Modal                                                                                                                                                         |
| `fullScreen`             | Boolean          |                          | Display modal as full screen                                                                                                                                               |
| `hasModalCard`           | Boolean          | true                     | If your modal content has a `.modal-card` as root, add this prop or the card might break on mobile                                                                         |
| `animation`              | String           |                          | Custom animation (transition name)                                                                                                                                         |
| `canCancel`              | Boolean, Array   | `escape`, `x`, `outside` | Can close Modal by clicking 'X', pressing escape or clicking outside                                                                                                       |
| `onCancel`               | Function         |                          | Callback function to call after user canceled (clicked 'X' / pressed escape / clicked outside)                                                                             |
| `scroll`                 | String           | `clip`, `keep`           | clip to remove the <body> scrollbar, keep to have a non scrollable scrollbar to avoid shifting background, but will set <body> to position fixed, might break some layouts |
| `trapFocus`              | Boolean          |                          | Trap focus inside the modal.                                                                                                                                               |
| `autoFocus`              | Boolean          |                          | Automatically focus modal when active.                                                                                                                                     |
| `customClass`            | String           |                          | CSS classes to be applied on modal                                                                                                                                         |
| `destroyOnHide`          | Boolean          |                          | Destroy modal on hide                                                                                                                                                      |
| `ariaRole`               | String           | `dialog`, `alertdialog`  | Role attribute to be passed to modal container for better accessibility.                                                                                                   |
| `ariaLabel`              | String           |                          | Aria label attribute to be passed to modal container for better accessibility.                                                                                             |
| `ariaModal`              | Boolean          |                          | Improve accessiblity when enabled.                                                                                                                                         |
| `size`              | String          |            `small`              | Change the width of the modal, it can be `small`, `medium`, `large`, `extraLarge`                                                                                                                                         |


TODO: add inverted look

## Available slots

| Slot name     | Description                         | Props (if scoped) |
| ------------- | ----------------------------------- | ----------------- |
| `default`     | Places content in body of the modal |                   |
| `modalFooter` | Renders content in the modal footer |                   |

## Available events

| Event name | Description                                                      |
| ---------- | ---------------------------------------------------------------- |
| `close`    | The close event is emitted when the modal close method is called |
