import { withKnobs, boolean, select, text } from '@storybook/addon-knobs';

import SmileModal from './smile-modal.vue';
import SmileImage from '../smile-image/smile-image.vue';
import SmileButton from '../smile-button/SmileButton.vue';
import componentDocs from './smile-modal.md';

export default {
  title: 'Vue Components / SmileModal',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const smileModal = () => ({
  components: { SmileModal, SmileImage, SmileButton },
  props: {
    size: {
      type: String,
      default: select('size', ['small', 'medium', 'large'], 'medium'),
    },
    fullScreen: {
      default: boolean('fullScreen', false),
      type: Boolean,
    },
    canCancel: {
      default: boolean('canCancel', true),
      type: Boolean,
    },
    hasSecondaryBackground: {
      default: boolean('hasSecondaryBackground', false),
      type: Boolean,
    },
    bodyContent: {
      type: String,
      default: text(
        'bodyContent',
        `<h1 class="title is-2">Join the club.</h1>
          <br />
          <div class="columns is-gapless is-multiline">
            <div class="column is-12" style="margin: 10px 0;">
              <div class="field">
                <label class="label">Zip Code</label>
                <div class="control">
                  <input class="input" type="text" placeholder="e.g. 12345">
                </div>
              </div>
            </div>
            <div class="column is-12" style="margin: 10px 0;">
              <div class="field">
                <label class="label">Email</label>
                <div class="control">
                  <input class="input" type="text" placeholder="e.g. example@gmail.com">
                </div>
              </div>
            </div>
          </div>
        `
      ),
    },
    footerContent: {
      type: String,
      default: text(
        'footerContent',
        `
        <button
          style="width: 130px"
          class="button is-primary is-large is-rounded"
        >
          Continue
        </button>
        `
      ),
    },
  },
  data: () => ({
    src: 'https://via.placeholder.com/300x200',
    alt: 'Visit the dentist',
    isActive: false,
    buttonText: 'Open Modal',
    type: 'is-primary',
    buttonSize: 'is-large',
    tag: 'button',
    outlined: true,
    loading: false,
    expanded: false,
  }),
  methods: {
    onClick() {
      this.isActive = true;
    },
    closeModal() {
      this.isActive = false;
    },
  },
  template: `
  <div>
    <smile-button :onClick="onClick" :expanded="expanded" :buttonText="buttonText" :buttonStyles="type" :buttonSize="buttonSize" :buttonTag="tag" :outlined="outlined" :loading="loading"></smile-button>
    <smile-modal :key="size" :isActive="isActive" :size="size" :fullScreen="fullScreen" :canCancel="canCancel" :onCancel="closeModal" :hasSecondaryBackground="hasSecondaryBackground">
      <template>
       <div v-html="bodyContent" />
      </template>
      <template #modalFooter>
        <div v-html="footerContent" />
      </template>
    </smile-modal>
  </div>
  `,
});
