import { withKnobs, text, boolean } from '@storybook/addon-knobs';
import SmileNavbar from './smile-navbar.vue';
import componentDocs from './smile-navbar.md';

export default {
  title: 'Vue Components / SmileNavBar',
  decorators: [withKnobs],
  parameters: {
    notes: { componentDocs },
    layout: 'fullscreen',
  },
};

export const Full = () => ({
  components: { SmileNavbar },
  props: {
    withUtilityBar: {
      type: Boolean,
      default: boolean('withUtilityBar', true),
    },
    logoPartDirectClub: {
      type: Boolean,
      default: boolean('logoPartDirectClub', true),
    },
    logoHref: {
      type: String,
      default: text('logoHref', 'https://smiledirectclub.com/'),
    },
    amIACandidateHref: {
      type: String,
      default: text('amIACandidateHref', 'https://smiledirectclub.com/smile_assessment/'),
    },
    bodyOverlay: {
      type: Boolean,
      default: boolean('bodyOverlay', true),
    },
    utilityCountryCode: {
      type: String,
      default: text('utilityCountryCode', 'us'),
    },
    utilityPhoneNumber: {
      type: String,
      default: text('utilityPhoneNumber', '1-800-848-7566'),
    },
    toggleGettingStarted: {
      type: Boolean,
      default: boolean('toggleGettingStarted', true),
    },
    isSideBarMenu: {
      type: Boolean,
      default: boolean('Hide desktop menu', false),
    },
  },
  data() {
    return {
      mainNavbarItems: [
        {
          key: 1,
          text: 'Why SDC?',
          href: 'https://smiledirectclub.com/why-smile-direct-club/',
          targetBlank: true,
        },
        {
          key: 2,
          text: 'How it works',
          href: 'https://smiledirectclub.com/how_it_works/',
          targetBlank: false,
        },
        {
          key: 3,
          text: 'Results',
          href: 'https://smiledirectclub.com/results/',
          targetBlank: false,
        },
      ],
    };
  },
  methods: {
    handleCountryFlag() {
      alert('Clicked on country flag');
    },
    handleLivChat() {
      alert('Clicked on live chat');
    },
    handleSignIn() {
      alert('Clicked on sign in');
    },
    handleGetStarted() {
      alert('Clicked on get started');
    },
  },
  template: `
    <div
      style="position: absolute; width: 100%; background-color: #e0e0e0"
    >
      <smile-navbar
        :with-utility-bar="withUtilityBar"
        :logo-part-direct-club="logoPartDirectClub"
        :logo-href="logoHref"
        :am-i-a-candidate-href="amIACandidateHref"
        :body-overlay="bodyOverlay"
        :utility-country-code="utilityCountryCode"
        :utility-phone-number="utilityPhoneNumber"
        :main-navbar-items="mainNavbarItems"
        :toggle-getting-started="toggleGettingStarted"
        :is-side-bar-menu="isSideBarMenu"
        @onClickCountryFlag="handleCountryFlag"
        @onClickLiveChat="handleLivChat"
        @onClickSignIn="handleSignIn"
        @onClickGetStarted="handleGetStarted"
        style="position: absolute"
      />
      <div style="height: 200px; margin: 200px 20px 0 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
    </div>
  `,
});

export const Condensed = () => ({
  components: { SmileNavbar },
  props: {
    logoHref: {
      type: String,
      default: text('logoHref', 'https://smiledirectclub.com/'),
    },
    amIACandidateHref: {
      type: String,
      default: text('amIACandidateHref', 'https://smiledirectclub.com/smile_assessment/'),
    },
    toggleGettingStarted: {
      type: Boolean,
      default: boolean('toggleGettingStarted', true),
    },
  },
  data() {
    return {
      mainNavbarItems: [
        {
          key: 1,
          text: 'Why SDC?',
          href: 'https://smiledirectclub.com/why-smile-direct-club/',
          targetBlank: true,
        },
        {
          key: 2,
          text: 'How it works',
          href: 'https://smiledirectclub.com/how_it_works/',
          targetBlank: false,
        },
        {
          key: 3,
          text: 'Results',
          href: 'https://smiledirectclub.com/results/',
          targetBlank: false,
        },
      ],
    };
  },
  methods: {
    handleGetStarted() {
      alert('Clicked on get started');
    },
  },
  template: `
    <div
      style="position: absolute; width: 100%; background-color: #e0e0e0"
    >
      <smile-navbar
        :with-utility-bar="false"
        :logo-part-direct-club="false"
        :logo-href="logoHref"
        :am-i-a-candidate-href="amIACandidateHref"
        :main-navbar-items="mainNavbarItems"
        :toggle-getting-started="toggleGettingStarted"
        @onClickGetStarted="handleGetStarted"
        style="position: absolute"
      />
      <div style="height: 200px; margin: 200px 20px 0 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
      <div style="height: 200px; margin: 20px; background-color: #b3b3b3; border-radius: 5px;"></div>
    </div>
  `,
});
