# Smile Notification

This component is extended from Buefy's `b-Notification` component. https://buefy.org/documentation/Notification.

Use this component to display a block of content to alert the user of something.

## Available Props

| Prop           | Type    | Required? | Default value | Description                                                                                                                         |
| -------------- | ------- | --------- | ------------- | ----------------------------------------------------------------------------------------------------------------------------------- |
| `active`       | Boolean | [x]       | `true`        | The initial state of the component.                                                                                                 |
| `is-light`     | Boolean | [ ]       | `false`       | Whether the component should add the `'is light'` class.                                                                            |
| `closable`     | Boolean | [ ]       | `false`       | Adds an 'X' button that closes the notification.                                                                                    |
| `type`         | String  | [ ]       | `is-primary`  | Type of the select `is-primary`, `is-white`, `is-black`, `is-light`, `is-dark`, `is-info`, `is-success`, `is-warning`, `is-danger`. |
| `auto-close`   | Boolean | [ ]       | `false`       | Hide notification after `duration` prop value has been added.                                                                       |
| `duration`     | Number  | [ ]       |               | Visibility duration of the notification component in miliseconds.                                                                   |
| `progress-bar` | Boolean | [ ]       | `false`       | Shows a progress bar remaining seconds before the alert will close.                                                                 |
| `animation`    | String  | [ ]       | `fade`        | Custom animation (transition name).                                                                                                 |
| `has-icon`     | Boolean | [ ]       | `false`       | Adds an icon on the left side depending on the type (or the icon prop if defined), We are using Feather Icons (fe) icons.           |
| `icon`         | String  | [ ]       |               | Icon name to use with has-icon.                                                                                                     |

## Available Events

| Event name           | Description                                             |
| -------------------- | ------------------------------------------------------- |
| `close-notification` | Emitted whenever b-notification emmits a `close` event. |

## Basic Usage

```html
<template>
	<smile-notification
		:active="active"
		:autoClose="autoClose"
		:duration="duration"
		:progressBar="progressBar"
		:animation="animation"
		:type="type"
	>
		<div v-html="innerNotificationHtml" />
	</smile-notification>
</template>

<script>
	// This is just an example of how you might get the data you need to pass to the
	// smile-notification component. Your implementation might need other details in
	// the parent component such as: name, components, etc.
	export default {
		props: {
			content: {
				type: Object,
				required: true,
			},
		},
		data() {
			return {
				active: false,
				autoClose: false,
				duration: 3000,
				progressBar: false,
				isLight: false,
				closable: false,
				type: 'is-warning',
			};
		},
		methods: {
			closeNotification() {
				// whatever you want to do here...
			},
			innerNotificationHtml() {
				return this.content?.somewhere?.here?.is?.the?.content;
			},
		},
	};
</script>
```

## Usage with Icon

```html
<template>
	<smile-notification :active="active" :hasIcon="hasIcon" :icon="icon">
		<div v-html="innerNotificationHtml" />
	</smile-notification>
</template>

<script>
	// This is just an example of how you might get the data you need to pass to the
	// smile-notification component. Your implementation might need other details in
	// the parent component such as: name, components, etc.
	export default {
		props: {
			content: {
				type: Object,
				required: true,
			},
		},
		data() {
			return {
				active: false,
				hasIcon: true,
				icon: 'settings',
				queue: false
				indefinite: false
				pauseOnHover: false

			};
		},
		methods: {
			closeNotification() {
				// whatever you want to do here...
			},
			innerNotificationHtml() {
				return this.content?.somewhere?.here?.is?.the?.content;
			},
		},
	};
</script>
```
