/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';
import { action } from '@storybook/addon-actions';
import { withKnobs, boolean, text, select, number } from '@storybook/addon-knobs';

import SmileNotification from './smile-notification.vue';
import SmileButton from '../smile-button/SmileButton.vue';
import SmileNotificationDocs from './smile-notification.md';

storiesOf('Vue Components / SmileNotification', module)
  .addParameters({ notes: { SmileNotificationDocs } })
  .addDecorator(
    withKnobs({
      escapeHTML: false,
    })
  )
  .add('Smile Notification', () => ({
    components: { SmileNotification },
    props: {
      innerNotificationHtml: {
        default: text(
          'Content',
          'Black Friday deals: $12 impression kit (free after rebate) + free 6-month whitening kit with code SMILES4GIFTS.'
        ),
        type: String,
      },
      active: {
        default: boolean('Active', true),
        type: Boolean,
      },
      isLight: {
        default: boolean('isLight', false),
        type: Boolean,
      },
      closable: {
        default: boolean('closable', true),
        type: Boolean,
      },
      type: {
        type: String,
        default: select(
          'Type',
          [
            'is-primary',
            'is-white',
            'is-black',
            'is-light',
            'is-dark',
            'is-info',
            'is-success',
            'is-warning',
            'is-danger',
          ],
          ''
        ),
      },
    },

    methods: {
      closeNotification: action('Notification closed'),
    },
    template: `
      <smile-notification
        :active="active"
        :isLight="isLight"
        :closable="closable"
        :type="type"
        @close-notification="closeNotification"
      >
        <div v-html="innerNotificationHtml"/>
      </smile-notification>
    `,
  }))
  .add('Smile Notification with auto-close', () => ({
    components: { SmileNotification, SmileButton },
    props: {
      innerNotificationHtml: {
        default: text(
          'Content',
          'Black Friday deals: $12 impression kit (free after rebate) + free 6-month whitening kit with code SMILES4GIFTS.'
        ),
        type: String,
      },
      autoClose: {
        default: boolean('AutoClose', true),
        type: Boolean,
      },
      duration: {
        type: Number,
        default: number('Duration', 3000),
      },
      progressBar: {
        default: boolean('ProgressBar', true),
        type: Boolean,
      },
      animation: {
        default: text('animation', 'fade'),
        type: String,
      },
    },
    data() {
      return {
        active: true,
      };
    },
    methods: {
      onClick() {
        this.active = !this.active;
      },
    },
    template: `
      <div>
        <smile-notification
          :active="active"
          :autoClose="autoClose"
          :duration="duration"
          :progressBar="progressBar"
        >
          <div v-html="innerNotificationHtml"/>
        </smile-notification>

        <smile-button :onClick="onClick" buttonSize="is-medium" buttonStyles="is-primary" buttonTag="button" buttonText="Click me"/>
      </div>
    `,
  }))
  .add('Smile Notification with icon', () => ({
    components: { SmileNotification },
    props: {
      innerNotificationHtml: {
        default: text(
          'Content',
          'Black Friday deals: $12 impression kit (free after rebate) + free 6-month whitening kit with code SMILES4GIFTS.'
        ),
        type: String,
      },
      hasIcon: {
        default: boolean('hasIcon', true),
        type: Boolean,
      },
      icon: {
        type: String,
        default: text('icon', 'settings'),
      },
    },
    data() {
      return {
        active: true,
      };
    },
    template: `
      <smile-notification
        :active="active"
        :hasIcon="hasIcon"
        :icon="icon"
      >
        <div v-html="innerNotificationHtml"/>
      </smile-notification>
    `,
  }));
