import {
  withKnobs, text, boolean,
} from '@storybook/addon-knobs';
import SmileRadio from './smile-radio.vue';
import componentDocs from './smile-radio.md';

export default {
  title: 'Vue Components / SmileRadio',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const RadioGroup = () => ({
  components: { SmileRadio },
  props: {
    storybookSlot1: {
      type: String,
      default: text('Slot 1', 'Label 1'),
    },
    storybookSlot2: {
      type: String,
      default: text('Slot 2', 'Label 2'),
    },
    storybookSlot3: {
      type: String,
      default: text('Slot 3', 'Label 3'),
    },
    storybookNativeValue1: {
      type: String,
      default: text('nativeValue 1', 'Value 1'),
    },
    storybookNativeValue2: {
      type: String,
      default: text('nativeValue 2', 'Value 2'),
    },
    storybookNativeValue3: {
      type: String,
      default: text('nativeValue 3', 'Value 3'),
    },
    storybookDisabled1: {
      type: Boolean,
      default: boolean('disabled 1', false),
    },
    storybookDisabled2: {
      type: Boolean,
      default: boolean('disabled 2', false),
    },
    storybookDisabled3: {
      type: Boolean,
      default: boolean('disabled 3', false),
    },
    legacyDesign1: {
      type: Boolean,
      default: boolean('legacyDesign 1', false),
    },
    legacyDesign2: {
      type: Boolean,
      default: boolean('legacyDesign 2', false),
    },
    legacyDesign3: {
      type: Boolean,
      default: boolean('legacyDesign 3', false),
    },
  },
  data() {
    return {
      storybookSelectedValue: this.storybookNativeValue1,
    };
  },
  template: `
    <div>
      <smile-radio
        name="storybook-radio"
        v-model="storybookSelectedValue"
        :native-value="storybookNativeValue1"
        :disabled="storybookDisabled1"
        :legacy-design="legacyDesign1"
      >
        {{ storybookSlot1 }}
      </smile-radio>
      <smile-radio
        name="storybook-radio"
        v-model="storybookSelectedValue"
        :native-value="storybookNativeValue2"
        :disabled="storybookDisabled2"
        :legacy-design="legacyDesign2"
      >
        {{ storybookSlot2 }}
      </smile-radio>
      <smile-radio
        name="storybook-radio"
        v-model="storybookSelectedValue"
        :native-value="storybookNativeValue3"
        :disabled="storybookDisabled3"
        :legacy-design="legacyDesign3"
      >
        {{ storybookSlot3 }}
      </smile-radio>
      <hr>
      <p><span class="has-text-weight-semibold has-text-black">Selection:</span> {{ storybookSelectedValue }}</p>
    </div>
  `,
});

export const RadioLegacyDesign = () => ({
  components: { SmileRadio },
  props: {
    storybookSlot1: {
      type: String,
      default: text('Slot 1', 'Label 1'),
    },
    storybookSlot2: {
      type: String,
      default: text('Slot 2', 'Label 2'),
    },
    storybookNativeValue1: {
      type: String,
      default: text('nativeValue 1', 'Value 1'),
    },
    storybookNativeValue2: {
      type: String,
      default: text('nativeValue 2', 'Value 2'),
    },
    storybookDisabled1: {
      type: Boolean,
      default: boolean('disabled 1', false),
    },
    storybookDisabled2: {
      type: Boolean,
      default: boolean('disabled 2', false),
    },
    legacyDesign1: {
      type: Boolean,
      default: boolean('legacyDesign 1', true),
    },
    legacyDesign2: {
      type: Boolean,
      default: boolean('legacyDesign 2', true),
    },
  },
  mounted() {
    if (!this.legacyDesign1 && !this.legacyDesign2) {
      this.legacyDesign1 = true;
      this.legacyDesign2 = true;
    }
  },
  data() {
    return {
      storybookSelectedValue: this.storybookNativeValue1,
    };
  },
  template: `
    <div>
      <smile-radio
        name="storybook-radio"
        v-model="storybookSelectedValue"
        :native-value="storybookNativeValue1"
        :disabled="storybookDisabled1"
        :legacy-design="legacyDesign1"
      >
        {{ storybookSlot1 }}
      </smile-radio>
      <smile-radio
        name="storybook-radio"
        v-model="storybookSelectedValue"
        :native-value="storybookNativeValue2"
        :disabled="storybookDisabled2"
        :legacy-design="legacyDesign2"
      >
        {{ storybookSlot2 }}
      </smile-radio>
      <hr>
      <p><span class="has-text-weight-semibold has-text-black">Selection:</span> {{ storybookSelectedValue }}</p>
    </div>
  `,
});
