# Smile Select

This component is extended from Buefy's `b-select` component. https://buefy.org/documentation/select

Use select when your user needs to select between a group of options.

## Available Props

| Prop                  | Type            | Required/Optional | Default value    | Description                                                                                                                                                                                          |
| --------------------- | --------------- | ----------------- | ---------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `selectId`            | String          | Optional          | -                | Same as native HTML id property.                                                                                                                                                                     |
| `selectName`          | String          | Optional          | -                | Same as native HTML name property.                                                                                                                                                                   |
| `value`               | [String, Array] | Optional          | -                | Default value.                                                                                                                                                                                       |
| `multiple`            | Boolean         | Optional          | -                | Same as native HTML `multiple` property.                                                                                                                                                             |
| `placeholder`         | String          | Optional          | Select an option | Text when nothing is selected.                                                                                                                                                                       |
| `size`                | String          | Required          | `is-large`       | Size of the select `is-small`, `is-medium`, `is-large`.                                                                                                                                              |
| `expanded`            | Boolean         | Required          | -                | Select will be expanded (full-width).                                                                                                                                                                |
| `options`             | Array           | Required          | []               | Pass options array to select dropdown initialization. This array can be populated with either primitive values or with objects with `key` and `value` properties.                                    |
| `disabled`            | Boolean         | Optional          | -                | Same as native HTML `disabled` property.                                                                                                                                                             |
| `select-first-option` | Boolean         | Optional          | -                | Select the first option by default. An options array with at least one element needs to be passed for this to work properly. It does not work when the options are set declaratively using the slot. |
| `type`                | String          | Optional          | -                | Type of the select `is-primary`, `is-white`, `is-black`, `is-light`, `is-dark`, `is-info`, `is-success`, `is-warning`, `is-danger`.                                                                  |
| `legacy-design`       | Boolean         | Optional          | false            | Makes the component look like old Vulcan pages.                                                                                                                                                      |

## Available Events

| Event name | Description                                                                                                                                                                                                                                                       |
| ---------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `input`    | Emitted on every update of the selected option of this component. It's also emited by the `create` hook of the component if the `select-first-option` prop was set to `true`, in which case it's emitted with the value of the first item in the `options` array. |

## Basic Usage

Only passing the value for the props that are required.

```html
<smile-select v-model="color" size="is-large" :expanded="true">
	<option>Black</option>
	<option>White</option>
	<option>Red</option>
</smile-select>
```

## Passing options

There are two different ways to pass `options`, you can either pass an array of primitives or an array of objects with `key` and `value` properties.

```html
<smile-select
	v-model="allergies"
	size="is-large"
	:expanded="true"
	:multiple="true"
	:options="['Grass and tree pollen', 'Dust mites', 'Dairy products']"
/>

<!-- OR -->

<smile-select
	v-model="allergies"
	size="is-large"
	:expanded="true"
	:multiple="true"
	:options="[{ key: 1, value: 'Grass and tree pollen' }, { key: 2, value: 'Dust mites' }, { key: 3, value: 'Dairy products' }]"
/>
```

## With SmileField

```html
<smile-field :label="label" :type="type">
	<smile-select
		v-model="monthOfBirth"
		size="is-medium"
		:disabled="disabled"
		:expanded="expanded"
		:multiple="multiple"
		:options="months"
		:placeholder="placeholder"
		:select-first-option="true"
		:type="type"
	/>
</smile-field>
```
