/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';

import { action } from '@storybook/addon-actions';
import { withKnobs, select, boolean, array, text } from '@storybook/addon-knobs';

import SmileSelect from './smile-select.vue';
import SmileField from '../smile-field/smile-field.vue';
import componentDocs from './smile-select.md';

storiesOf('Vue Components / SmileSelect', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'Select with add options',
    () => ({
      components: { SmileSelect },
      props: {
        selectId: {
          type: String,
          default: text('Select id', 'select-with-add-options'),
        },
        selectName: {
          type: String,
          default: text('Select name', 'select-with-add-options'),
        },
        placeholder: {
          type: String,
          default: text('Placeholder', 'Select an option'),
        },
        size: {
          type: String,
          default: select('Size', ['is-large', 'is-medium', 'is-small'], 'is-large'),
        },
        options: {
          type: Array,
          default: array('Options', ['option 1', 'option 2', 'option 3', 'option 4']),
        },
        expanded: {
          type: Boolean,
          default: boolean('Expanded', true),
        },
        disabled: {
          type: Boolean,
          default: boolean('Disabled', false),
        },
        selectFirstOption: {
          type: Boolean,
          default: boolean('Select first option by default'),
        },
        multiple: {
          type: Boolean,
          default: boolean('Multiple'),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', false),
        },
      },
      methods: {
        action: action('Option selected'),
      },
      template: `
      <smile-select
        :selectId="selectId"
        :selectName="selectName"
        :multiple="multiple"
        :size="size"
        :expanded="expanded"
        :disabled="disabled"
        :options="options"
        :placeholder="placeholder"
        :select-first-option="selectFirstOption"
        :legacy-design="legacyDesign"
        @input="action"
      />
      `,
    }),
    { info: true }
  )
  .add(
    'Select using <slot> with <optgroup>',
    () => ({
      components: { SmileSelect },
      props: {
        selectId: {
          type: String,
          default: text('Select Id', 'select-usign-slot'),
        },
        selectName: {
          type: String,
          default: text('Select name', 'select-usign-slot'),
        },
        placeholder: {
          type: String,
          default: text('Placeholder', 'Select an option'),
        },
        size: {
          type: String,
          default: select('Size', ['is-large', 'is-medium', 'is-small'], 'is-large'),
        },
        expanded: {
          type: Boolean,
          default: boolean('Expanded', true),
        },
        disabled: {
          type: Boolean,
          default: boolean('Disabled', false),
        },
        selectFirstOption: {
          type: Boolean,
          default: boolean('Select first option by default'),
        },
        multiple: {
          type: Boolean,
          default: boolean('Multiple'),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', false),
        },
      },
      methods: {
        action: action('Option selected'),
      },
      template: `
      <smile-select
        :selectId="selectId"
        :selectName="selectName"
        :multiple="multiple"
        :size="size"
        :expanded="expanded"
        :disabled="disabled"
        :placeholder="placeholder"
        :select-first-option="selectFirstOption"
        :legacy-design="legacyDesign"
        @input="action"
      >
        <option>Option 1</option>
        <option>Option 2</option>
        <optgroup label="Group label" disabled>
          <option>Disabled Grouped Option 1</option>
          <option>Disabled Grouped Option 2</option>
        </optgroup>
        <option>Option 3</option>
        <option>Option 4</option>
        <optgroup label="Group label">
          <option>Grouped Option 3</option>
          <option>Grouped Option 4</option>
        </optgroup>
      </smile-select>
      `,
    }),
    { info: true }
  )
  .add(
    'Select with array of object',
    () => ({
      components: { SmileSelect },
      props: {
        selectId: {
          type: String,
          default: text('Select id', 'select-with-array'),
        },
        selectName: {
          type: String,
          default: text('Select name', 'select-with-array'),
        },
        placeholder: {
          type: String,
          default: text('Placeholder', 'Select an option'),
        },
        size: {
          type: String,
          default: select('Size', ['is-large', 'is-medium', 'is-small'], 'is-large'),
        },
        expanded: {
          type: Boolean,
          default: boolean('Expanded', true),
        },
        disabled: {
          type: Boolean,
          default: boolean('Disabled', false),
        },
        selectFirstOption: {
          type: Boolean,
          default: boolean('Select first option by default'),
        },
        multiple: {
          type: Boolean,
          default: boolean('Multiple'),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', false),
        },
      },
      data() {
        return {
          options: [
            {
              key: 'OPT1',
              value: 'Option 1',
            },
            {
              key: 'OPT2',
              value: 'Option 2',
            },
            {
              key: 'OPT3',
              value: 'Option 3',
            },
            {
              key: 'OPT4',
              value: 'Option 4',
            },
          ],
        };
      },
      methods: {
        action: action('Option selected'),
      },
      template: `
      <smile-select
        :selectId="selectId"
        :selectName="selectName"
        :multiple="multiple"
        :size="size"
        :expanded="expanded"
        :disabled="disabled"
        :options="options"
        :placeholder="placeholder"
        :select-first-option="selectFirstOption"
        :legacy-design="legacyDesign"
        @input="action"
      >
      </smile-select>
      `,
    }),
    { info: true }
  )
  .add(
    'Select with add options and SmileField',
    () => ({
      components: { SmileSelect, SmileField },
      props: {
        selectId: {
          type: String,
          default: text('Select id', 'select-smile-field'),
        },
        selectName: {
          type: String,
          default: text('Select name', 'select-smile-field'),
        },
        placeholder: {
          type: String,
          default: text('Placeholder', 'Select an option'),
        },
        size: {
          type: String,
          default: select('Size', ['is-large', 'is-medium', 'is-small'], 'is-large'),
        },
        options: {
          type: Array,
          default: array('Options', ['option 1', 'option 2', 'option 3', 'option 4']),
        },
        expanded: {
          type: Boolean,
          default: boolean('Expanded', true),
        },
        disabled: {
          type: Boolean,
          default: boolean('Disabled', false),
        },
        selectFirstOption: {
          type: Boolean,
          default: boolean('Select first option by default'),
        },
        multiple: {
          type: Boolean,
          default: boolean('Multiple'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            ''
          ),
        },
        label: {
          type: String,
          default: text('Label', 'Input Label'),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', false),
        },
      },
      methods: {
        action: action('Option selected'),
      },
      template: `
      <smile-field
        :label="label"
        :type="type"
      >
      <smile-select
        :selectId="selectId"
        :selectName="selectName"
        :multiple="multiple"
        :size="size"
        :expanded="expanded"
        :disabled="disabled"
        :options="options"
        :placeholder="placeholder"
        :select-first-option="selectFirstOption"
        :type="type"
        :legacy-design="legacyDesign"
        @input="action"
      >
      </smile-select>
    </smile-field>
      `,
    }),
    { info: true }
  )
  .add(
    'Select with legacy design',
    () => ({
      components: { SmileSelect, SmileField },
      props: {
        selectId: {
          type: String,
          default: text('Select id', 'selec-legacy-design'),
        },
        selectName: {
          type: String,
          default: text('Select name', 'selec-legacy-design'),
        },
        placeholder: {
          type: String,
          default: text('Placeholder', 'Select an option'),
        },
        size: {
          type: String,
          default: select('Size', ['is-large', 'is-medium', 'is-small'], 'is-large'),
        },
        options: {
          type: Array,
          default: array('Options', ['option 1', 'option 2', 'option 3', 'option 4']),
        },
        expanded: {
          type: Boolean,
          default: boolean('Expanded', true),
        },
        disabled: {
          type: Boolean,
          default: boolean('Disabled', false),
        },
        selectFirstOption: {
          type: Boolean,
          default: boolean('Select first option by default'),
        },
        multiple: {
          type: Boolean,
          default: boolean('Multiple'),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('Legacy Design', true),
        },
      },
      mounted() {
        if (!this.legacyDesign) {
          this.legacyDesign = true;
        }
      },
      methods: {
        action: action('Option selected'),
      },
      template: `
      <smile-select
        :selectId="selectId"
        :selectName="selectName"
        :multiple="multiple"
        :size="size"
        :expanded="expanded"
        :disabled="disabled"
        :options="options"
        :placeholder="placeholder"
        :select-first-option="selectFirstOption"
        :legacy-design="legacyDesign"
        @input="action"
      >
      </smile-select>
      `,
    }),
    { info: true }
  );
