import {
  withKnobs, text, select, number, boolean,
} from '@storybook/addon-knobs';
import SmileSnackbar from './smile-snackbar.vue';

export default {
  title: 'Vue Components / SmileSnackbar',
  decorators: [withKnobs],
};

export const SnackbarComponent = () => ({
  components: { SmileSnackbar },
  props: {
    type: {
      type: String,
      default: select(
        'Type',
        [
          'is-success',
          'is-white',
          'is-black',
          'is-light',
          'is-dark',
          'is-primary',
          'is-info',
          'is-warning',
          'is-danger',
        ],
        'is-success',
      ),
    },
    message: {
      type: String,
      default: text('Custom message', 'SDC Message'),
    },
    onAction: {
      type: Function,
      default: () => {
        alert('Action pressed!');
      },
    },
    actionText: {
      type: String,
      default: text('Action text', 'OK'),
    },
    duration: {
      type: Number,
      default: number('Duration', 3500, { min: 100, step: 100 }),
    },
    indefinite: {
      type: Boolean,
      default: boolean('Indefinite', false),
    },
  },
  data() {
    return {
      showSnackbar: false,
    };
  },
  methods: {
    start() {
      this.showSnackbar = true;
    },
  },
  template: `
    <div>
      <b-button
        label="Show Snackbar!"
        size="is-medium"
        type="is-primary"
        @click="start"
      />
      <smile-snackbar
        v-model="showSnackbar"
        :message="message"
        :type="type"
        :actionText="actionText"
        :onAction="onAction"
        :duration="duration"
        :indefinite="indefinite"
      >
      </smile-snackbar>
    </div>
  `,
});
