/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import {
  withKnobs, text, select, boolean,
} from '@storybook/addon-knobs';

import SmileSteps from './smile-steps.vue';
import SmileStepsItem from './smile-steps-item.vue';
import componentDocs from './smile-steps.md';

storiesOf('Vue Components / SmileSteps', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'Smile Steps component',
    () => ({
      components: { SmileSteps, SmileStepsItem },
      props: {
        activeStep: {
          type: Number,
          default: select('Active Step', [0, 1, 2], 1),
        },
        type: {
          type: String,
          default: select('type', ['is-white', 'is-black', 'is-light', 'is-dark', 'is-primary', 'is-info', 'is-success', 'is-warning', 'is-danger'], 'is-primary'),
        },
        size: {
          type: String,
          default: select('size', ['is-small', 'is-medium', 'is-large'], 'is-small'),
        },
        labelPosition: {
          type: String,
          default: select('labelPosition', ['bottom', 'right', 'left'], 'bottom'),
        },
        mobileMode: {
          type: String,
          default: select('mobileMode', ['minimalist', 'compact', 'null'], 'compact'),
        },
        clickableStep1: {
          type: Boolean,
          default: boolean('clickableStep1', true),
        },
        clickableStep2: {
          type: Boolean,
          default: boolean('clickableStep2', true),
        },
        clickableStep3: {
          type: Boolean,
          default: boolean('clickableStep3', true),
        },
        legacyDesign: {
          type: Boolean,
          default: boolean('legacyDesign', false),
        }
      },
      template: `
      <div>
      <smile-steps
          v-model="activeStep"
          :activeStep="activeStep"
          :type="type"
          :size="size"
          :label-position="labelPosition"
          :mobileMode="mobileMode"
          :legacy-design="legacyDesign"
        >
          <smile-steps-item
            step="1"
            label="Summary"
            :clickable="clickableStep1"
          ></smile-steps-item>
          <smile-steps-item
            step="2"
            label="Shipping"
            :clickable="clickableStep2"
          ></smile-steps-item>
          <smile-steps-item
            step="3"
            label="Payment"
            :clickable="clickableStep3"
          ></smile-steps-item>
        </smile-steps>
        <p>Step Item active: {{ activeStep }} </p>
        <div>
    `,
    }),
    { info: true },
  );
