/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { withKnobs, select, text, boolean } from '@storybook/addon-knobs';

import SmileTabs from './smile-tabs.vue';
import SmileTabItem from './smile-tab-item.vue';
import componentDocs from './smile-tabs.md';

storiesOf('Vue Components / SmileTabs', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'Smile Tabs component',
    () => ({
      components: { SmileTabs, SmileTabItem },
      props: {
        activeTab: {
          type: Number,
          default: select('Active Tab', [0, 1, 2], 2),
        },
        size: {
          type: String,
          default: select('Size', ['', 'is-small', 'is-medium', 'is-large'], ''),
        },
        tabLabel: {
          type: String,
          default: text('Custom Label', 'Example'),
        },
        position: {
          type: String,
          default: select('Position', ['', 'is-centered', 'is-right'], ''),
        },
        disableTab: {
          type: Boolean,
          default: boolean('Disable tab item', false),
        },
      },
      template: `
        <smile-tabs
          v-model="activeTab"
          :size="size"
          :label="tabLabel"
          :position="position"
          :disableTab="disableTab"
        >
          <smile-tab-item
            label="Label 1"
            :disabled=false
          />
          <smile-tab-item
            label="Label 2"
            :disabled=false
          />
          <smile-tab-item
            :label="tabLabel"
            :disabled="disableTab"
          />
        </smile-tabs>
    `,
    }),
    { info: true }
  );
