import {
  withKnobs, text, boolean, select, number, array,
} from '@storybook/addon-knobs';
import SmileTelInput from './smile-tel-input.vue';
import componentDocs from './smile-tel-input.md';

export default {
  title: 'Vue Components / SmileTelInput',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const Basic = () => ({
  components: { SmileTelInput },
  data() {
    return {
      tel: '',
      preferredCountries: ['US', 'GB'],
    };
  },
  props: {
    errorMode: {
      type: Boolean,
      default: boolean('errorMode', false),
    },
    placeholder: {
      type: String,
      default: text('placeholcer', 'Enter your phone'),
    },
    mode: {
      type: String,
      default: select('mode', ['international', 'auto', 'national'], 'international'),
    },
  },
  computed: {
    inputOptions() {
      return {
        placeholder: this.placeholder,
      };
    },
  },
  template: `
    <div>
      <smile-tel-input
        :inputOptions="inputOptions"
        :mode="mode"
        :class="{'is-danger': errorMode}"
        :preferredCountries="preferredCountries"
        validCharactersOnly
        v-model="tel"
      />
      <p>v-model value: {{tel}}</p>
      <br/>
      <br/>
      <p>Note: There are many properties for this component, please check the attached documentation</p>
    </div>
  `,
});
