import { withKnobs, text, boolean, select, number, array } from '@storybook/addon-knobs';
import SmileTimeSlotPicker from './SmileTimeSlotPicker.vue';
import componentDocs from './SmileTimeSlotPicker.md';

export default {
  title: 'Vue Components / SmileTimeSlotPicker',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const Basic = () => ({
  components: { SmileTimeSlotPicker },
  props: {
    timeSlots: {
      default: array('Time Slots', []),
    },
  },
  data() {
    return {
      dates: [],
    };
  },
  methods: {
    setDates() {
      // You can change this variable to work with the UTC time
      let startingHour = 10;
      // get the current date in UTC
      let tomorrow = new Date();
      tomorrow.setDate(tomorrow.getDate() + 1);
      // getTimezoneOffset() returns the difference between UTC time and local time in minutes, then multiply by 60000 to get milliseconds.
      const timeOffsetUTC = tomorrow.getTimezoneOffset() * 60000;
      let currentDateUTC = new Date(tomorrow.valueOf() + timeOffsetUTC);
      currentDateUTC.setHours(0, 0, 0, 0);
      let i = 0;
      while (i < 18) {
        // This will add dates every 30 minutes starting with the startingHour
        const newDate = new Date(currentDateUTC.valueOf() + 3600000 * (startingHour + i / 2) - timeOffsetUTC);
        const formattedMinutes = `0${newDate.getUTCMinutes()}`.slice(-2);
        // newCreatedDate UTC without timezone at the end of the ISOString
        this.dates[i] = {};
        this.dates[i].appointmentUTCTime = newDate.toISOString().slice(0, -1);
        this.dates[i].appointmentStartTime = newDate.getUTCHours() + ':' + formattedMinutes;

        // sets appointments available to either 0, 1, or 2
        this.dates[i].availableAppointments = Math.floor(Math.random() * 3);
        i++;
      }
    },
  },
  created() {
    this.setDates();
    this.timeSlots = this.dates;
  },
  template: `
    <div>
      <smile-time-slot-picker
        :timeSlots="timeSlots"
      />
    </div>
  `,
});
