/* eslint-disable import/no-extraneous-dependencies */
import { storiesOf } from '@storybook/vue';
import componentDocs from './smile-toast.md';

import { withKnobs, select, boolean, text, number } from '@storybook/addon-knobs';

import SmileToast from './smile-toast.vue';
import SmileButton from '../smile-button/SmileButton.vue';

storiesOf('Vue Components / SmileToast', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'Smile Toast component',
    () => ({
      components: { SmileToast, SmileButton },
      props: {
        message: {
          type: String,
          default: text('Text', 'This is example text'),
        },
        type: {
          type: String,
          default: select(
            'Type',
            [
              'is-primary',
              'is-white',
              'is-text',
              'is-black',
              'is-light',
              'is-dark',
              'is-info',
              'is-success',
              'is-warning',
              'is-danger',
            ],
            'is-primary'
          ),
        },
        position: {
          type: String,
          default: select(
            'Position',
            ['is-top-right', 'is-top', 'is-top-left', 'is-bottom-right', 'is-bottom', 'is-bottom-left'],
            'is-top'
          ),
        },
        duration: {
          type: Number,
          default: number('Duration', 2000, { range: false, step: 1000 }),
        },
        queue: {
          type: Boolean,
          default: boolean('Queue', false),
        },
      },
      data() {
        return {
          show: false,
        };
      },
      methods: {
        onClick() {
          this.show = true;
        },
        finish() {
          this.show = false;
        },
      },
      template: `
          <div>
            <smile-toast :message="message" :queue="queue" :duration="duration" :type="type" :position="position" :show="show" @finish="finish"></smile-toast>
            <smile-button :onClick="onClick" buttonSize="is-medium" buttonStyles="is-primary" buttonTag="button" buttonText="Click me"/>
          </div>
      `,
    }),
    { info: true }
  );
