# Smile Tooltip

Our `smile-tooltip` component is based off of and extended from Buefy's `b-tooltip` component. https://buefy.org/documentation/tooltip

## Available Props

| Prop         | Type    | Required/Optional | Default value         | Description                                                                                                                           |
| ------------ | ------- | ----------------- | --------------------- | ------------------------------------------------------------------------------------------------------------------------------------- |
| `type`       | String  | Optional          | `is-primary`(Blurple) | Availabe type options: `'is-primary', 'is-white', 'is-black', 'is-dark', 'is-light', 'is-link', 'is-info', 'is-warning', 'is-danger'` |  |
| `active`     | Boolean | Optional          | `true`                | Used for show or hide tooltip.                                                                                                        |
| `label`      | String  | Optional          | `''`                  | Tooltip text.                                                                                                                         |
| `triggers`   | Array   | Optional          | `['hover']`           | Events that will trigger the tooltip. Available options: `click`, `hover`, `focus`, `contextmenu`.                                    |
| `position`   | String  | Optional          | `is-top`              | Tooltip position in relation of the element. Available options: `is-top`, `is-bottom`, `is-left` and `is-right`.                      |
| `always`     | Boolean | Optional          | `false`               | Tooltip will be always active.                                                                                                        |
| `animated`   | Boolean | Optional          | `true`                | Tooltip will have a little fade animation.                                                                                            |
| `square`     | Boolean | Optional          | `false`               | Tooltip will be square (not rounded corners).                                                                                         |
| `dashed`     | Boolean | Optional          | `false`               | Tooltip will have a dashed underline.                                                                                                 |
| `multilined` | Boolean | Optional          | `false`               | Tooltip will be multilined.                                                                                                           |
| `size`       | String  | Optional          | `is-medium`           | Tooltip multimile size (only work for multilined tooltips). Available options: `is-small`, `is-medium`, and `is-large`.               |
| `delay`      | Number  | Optional          | `0`                   | Tooltip delay before it appears.                                                                                                      |

## Slots

| Slot name | Description                              |
| --------- | ---------------------------------------- |
| `content` | Content that will appear in the tooltip. |

## Basic Usage

### Default

```html
<smile-tooltip label="Example tooltip"
	><button>Example button</button></smile-tooltip
>
```

### Getting fancy

```html
<smile-tooltip
	active
	always
	multilined
	square,
	dashed,
	size="is-small"
	label="Example tooltip"
	position="is-bottom"
	type="is-white"
>
	<button>Example button</button>
</smile-tooltip>
```

### Html content

```html
<smile-tooltip>
	<button>Example button</button>
	<template #content> Example <b>tooltip</b> </template>
</smile-tooltip>
```
