/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { withKnobs, select, text, array, number, boolean } from '@storybook/addon-knobs';

import SmileTooltip from './smile-tooltip.vue';
import SmileIcon from '../smile-icon/smile-icon.vue';
import componentDocs from './smile-tooltip.md';

storiesOf('Vue Components / SmileTooltip', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(
    withKnobs({
      escapeHTML: false,
    })
  )
  .add(
    'SmileTooltip',
    () => ({
      components: { SmileTooltip, SmileIcon },
      props: {
        type: {
          type: String,
          default: select(
            'type',
            [
              'is-primary',
              'is-white',
              'is-black',
              'is-dark',
              'is-light',
              'is-link',
              'is-info',
              'is-warning',
              'is-danger',
            ],
            'is-primary'
          ),
        },
        active: {
          type: Boolean,
          default: boolean('active', true),
        },
        label: {
          type: String,
          default: text(
            'label',
            'This is example label text. Label prop will take priority over the #content slot if both are populated.'
          ),
        },
        slotContent: {
          type: String,
          default: text(
            '#content slot',
            'You can use HTML in the <b>#content</b> template slot if you need more than a string.'
          ),
        },
        triggers: {
          type: Array,
          default: array('triggers', ['hover', 'click', 'focus', 'contextmenu']),
        },
        position: {
          type: String,
          default: select('position', ['is-top', 'is-bottom', 'is-left', 'is-right'], 'is-top'),
        },
        always: {
          type: Boolean,
          default: boolean('always', false),
        },
        animated: {
          type: Boolean,
          default: boolean('animated', true),
        },
        multilined: {
          type: Boolean,
          default: boolean('multilined', false),
        },
        size: {
          type: String,
          default: select('size', ['is-small', 'is-medium', 'is-large'], 'is-medium'),
        },
        delay: {
          type: Number,
          default: number('delay', 0),
        },
      },
      template: `
    <div class="is-flex is-justify-content-center is-align-items-center is-flex-direction-column">
      <smile-tooltip
        :type="type"
        :active="active"
        :label="label"
        :triggers="triggers"
        :position="position"
        :always="always"
        :animated="animated"
        :multilined="multilined"
        :size="size"
        :delay="delay"
        v-bind="$attrs"
        v-on="$listeners"
        class="smile-tooltip"
      >
        <smile-icon
          icon="info"
          type="is-primary"
          class="is-clickable"

        />
        <template #content>
          <div v-html="slotContent"/>
        </template>
      </smile-tooltip>
      <p class="title ml-5">The info icon has a tooltip associated with it.</p>
    </div>
    `,
    }),
    { info: true, layout: 'centered' }
  );
