# Smile Video

Our `smile-video` component is based off of html's `video` element: https://developer.mozilla.org/en-US/docs/Web/HTML/Element/video

## Available Props

| Prop                      | Type         | Required | Default value | Description                                                                                                                                                                                                                                                                                     |
| ------------------------- | ------------ | -------- | ------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `autoplay`                | Boolean      |          | `false`       | If true, the video automatically begins to play back as soon as it can do so without stopping to finish loading the data.                                                                                                                                                                       |
| `autoPictureInPicture`    | Boolean      |          | `false`       | If true indicates that the element should automatically toggle picture-in-picture mode when the user switches back and forth between this document and another document or application.                                                                                                         |
| `controls`                | Boolean      |          | `true`        | If this attribute is present, the browser will offer controls to allow the user to control video playback, including volume, seeking, and pause/resume playback. text.                                                                                                                          |
| `controlsList`            | String       |          | `""`          | The controlslist attribute, when specified, helps the browser select what controls to show on the media element whenever the browser shows its own set of controls (e.g. when the controls attribute is specified). The allowed values are `nodownload`, `nofullscreen` and `noremoteplayback`. |
| `disablePictureInPicture` | Boolean      |          | `false`       | Prevents the browser from suggesting a Picture-in-Picture context menu or to request Picture-in-Picture automatically in some cases.                                                                                                                                                            |
| `disableRemotePlayback`   | Boolean      |          | `false`       | A Boolean attribute used to disable the capability of remote playback in devices that are attached using wired (HDMI, DVI, etc.) and wireless technologies (Miracast, Chromecast, DLNA, AirPlay, etc).                                                                                          |
| `loop`                    | Boolean      |          | `false`       | A Boolean attribute; if specified, the browser will automatically seek back to the start upon reaching the end of the video.                                                                                                                                                                    |
| `muted`                   | Boolean      |          | `false`       | A Boolean attribute that indicates the default setting of the audio contained in the video. If set, the audio will be initially silenced. Its default value is false, meaning that the audio will be played when the video is played.                                                           |
| `playsinline`             | Boolean      |          | `false`       | A Boolean attribute indicating that the video is to be played "inline", that is within the element's playback area. Note that the absence of this attribute does not imply that the video will always be played in fullscreen.                                                                  |
| `preload`                 | String       |          | `metadata`    | This enumerated attribute is intended to provide a hint to the browser about what the author thinks will lead to the best user experience with regards to what content is loaded before the video is played.                                                                                    |
| `poster`                  | String       |          | `""`          | A URL for an image to be shown while the video is downloading. If this attribute isn't specified, nothing is displayed until the first frame is available, then the first frame is shown as the poster frame.                                                                                   |
| `videoName`               | String       | X        | `""`          | The name of the video that smile-video should load. This name is agnostic of where the video is hosted. NOTE: omit the file extension when passing the video name                                                                                                                               |
| `videoExtensionType`      | Enum(String) |          | `""`          | Used to specify the video format type. Not required if the `videoName` string already contains the correct extension type. Can be `.mp4`, `.webm`, `.m3u8`, or `""` to denote the video name already contains the extension                                                                     |

## Basic Usage

``` html
<smile-video videoName="name-of-video" />
```

For Cloudinary usage:

``` html
<smile-video videoName="base-cloudinary-url/cloudinary-space/name-of-video" />
```
