/* eslint-disable import/no-extraneous-dependencies */

import { storiesOf } from '@storybook/vue';

import { withKnobs, select, text } from '@storybook/addon-knobs';

import SmileVideo from './smile-video.vue';
import componentDocs from './smile-video.md';

const CLOUDINARY_BASE = '//res.cloudinary.com/smiledirectclub/video/upload/vc_auto/v1608657826';

storiesOf('Vue Components / SmileVideo', module)
  .addParameters({ notes: { componentDocs } })
  .addDecorator(withKnobs)
  .add(
    'Smile Video Component',
    () => ({
      components: { SmileVideo },
      props: {
        autoplay: {
          type: Boolean,
          required: false,
          default: select('Autoplay', [true, false], false),
        },
        autoPictureInPicture: {
          type: Boolean,
          required: false,
          default: select('Auto Picture-in-Picture', [true, false], true),
        },
        controls: {
          type: Boolean,
          required: false,
          default: select('Controls', [true, false], true),
        },
        controlsList: {
          type: String,
          required: false,
        },
        disablePictureInPicture: {
          type: Boolean,
          required: false,
          default: select('Disable Picture-in-Picture', [true, false], false),
        },
        disableRemotePlayback: {
          type: Boolean,
          required: false,
          default: select('Disable Remote Playback', [true, false], false),
        },
        loop: {
          type: Boolean,
          required: false,
          default: select('Loop', [true, false], false),
        },
        muted: {
          type: Boolean,
          required: false,
          default: select('Muted', [true, false], false),
        },
        playsinline: {
          type: Boolean,
          required: false,
          default: select('Plays Inline', [true, false], true),
        },
        preload: {
          type: String,
          required: false,
          default: select('Preload', ['none', 'metadata', 'auto'], 'metadata'),
        },
        poster: {
          type: String,
          required: false,
          default: '',
        },
        videoName: {
          type: String,
          required: true,
          default: text('Video Name', `${CLOUDINARY_BASE}/live-video.mp4`),
        },
        videoExtensionType: {
          type: String,
          required: false,
          default: text('Video Extension Type', ''),
        },
      },
      template: `
        <smile-video
          :autoplay="autoplay"
          :autoPictureInPicture="autoPictureInPicture"
          :controls="controls"
          :controlsList="controlsList"
          :disablePictureInPicture="disablePictureInPicture"
          :disableRemotePlayback="disableRemotePlayback"
          :loop="loop"
          :muted="muted"
          :playsinline="playsinline"
          :preload="preload"
          :poster="poster"
          :videoName="videoName"
          :videoExtensionType="videoExtensionType"
        />
    `,
    }),
    { info: true }
  );
