import {
  withKnobs, text, boolean,
} from '@storybook/addon-knobs';
import componentDocs from './payment-broker-prototype.md';
import SmileField from '/src/components/smile-field/smile-field.vue';
import SmileRadio from '/src/components/smile-radio/smile-radio.vue';
import SmileInput from '/src/components/smile-input/smile-input.vue';

export default {
  title: 'HTML & CSS / Prototypes',
  decorators: [withKnobs({ escapeHTML: false })],
  parameters: {
    notes: { componentDocs },
  },
};

export const PaymentBrokerUI = () => ({
  components: {
    SmileField,
    SmileRadio,
    SmileInput
  },
  template: `
  <div class="has-border has-radius">

      <!-- Credit Card panel -->
      <div class="payment-option-panel has-border-bottom is-clickable">
        <b-collapse
          :open="false">
          <template #trigger>
            <div class="p-3">
              <div class="columns is-mobile is-justify-content-space-between">
                <div class="column">
                  <smile-radio
                    name="payment-option"
                    class="pl-0"
                  >
                    Credit Card
                  </smile-radio>
                </div>
                <div class="column has-text-right">
                  [card icons]
                </div>
              </div>
            </div>
          </template>
          <div class="has-background-light p-3">

            <!-- Credit card form -->
            <form class="credit-card-form">
              <smile-field
                label="Name on card"
                label-for="credit-card-form"
                message="Error message here"
              >
                <smile-input/>
              </smile-field>

              <smile-field
                label="Card number"
                label-for="credit-card-form"
                message="Error message here"
              >
                <smile-input/>
              </smile-field>

              <div class="columns is-mobile">
                <div class="column">
                  <smile-field
                    label="Expiration"
                    label-for="credit-card-form"
                    message="Error message here"
                  >
                    <smile-input/>
                  </smile-field>
                </div>
                <div class="column">
                  <smile-field
                    label="Security code"
                    label-for="credit-card-form"
                    message="Error message here"
                  >
                    <smile-input
                      icon-right="help-circle"
                      icon-right-clickable
                      icon-pack="fe"
                    />
                  </smile-field>
                </div>
              </div>
            </form>

          </div>
        </b-collapse>
      </div>

      <!-- PayPal panel -->
      <div class="payment-option-panel has-border-bottom is-clickable">
        <div class="p-3">
          <div class="columns is-mobile is-justify-content-space-between">
            <div class="column is-three-quarters">
              <smile-radio
                name="payment-option"
                class="pl-0"
              >
                PayPal
              </smile-radio>
            </div>
            <div class="column has-text-right">
              [icon]
            </div>
          </div>
        </div>
      </div>

      <!-- Apple Pay panel -->
      <div class="payment-option-panel has-border-bottom is-clickable">
        <div class="p-3">
          <div class="columns is-mobile is-justify-content-space-between">
            <div class="column is-three-quarters">
              <smile-radio
                name="payment-option"
                class="pl-0"
              >
                Apple Pay
              </smile-radio>
            </div>
            <div class="column has-text-right">
              [icon]
            </div>
          </div>
        </div>
      </div>

      <!-- Google Pay panel -->
      <div class="payment-option-panel is-clickable">
        <div class="p-3">
          <div class="columns is-mobile is-justify-content-space-between">
            <div class="column is-three-quarters">
              <smile-radio
                name="payment-option"
                class="pl-0"
              >
                Google Pay
              </smile-radio>
            </div>
            <div class="column has-text-right">
              [icon]
            </div>
          </div>
        </div>
      </div>
    </div>`,
});
