# SCSS Variables & Mixins

We have a lot of existing SCSS variables to make use of when writing custom styles. These are both custom variables, and variables exposed by our underlying Bulma frameowrk.

We should always use any available variables, when appropriate, before hard coding a value. This will ensure consistency across all components in the CSS framework when making design updates.

* SDC Custom Variables File: https://github.com/smiledirectclub/component-library/blob/main/src/scss/global-variables.scss
* Bulma Variables: https://bulma.io/documentation/customize/variables/


Below is a list of frequently used variables and mixins within our system:

## Colors

| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$primary` | `#5700ff` | The SDC primary brand color "blurple". |
| `$black` | `#000000` | Default title/headline color |
| `$grey` | `#666666` | Default body copy color |
| `$grey-light` | `#b3b3b3` | - |
| `$grey-lighter` | `#e0e0e0` | - |
| `$grey-lightest` | `#f5f5f5` | Commonly used background color |
| `$white` | `#ffffff` | - |
| `$green` | `#008542` | Used for success states |
| `$red` | `#e91916` | Used for error / danger states |
| `$teal` | `#35c4d3` | A legacy color that should almost never be used unless you are needing to match legacy designs. |



## Text Related

### Font stack
| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$family-sans-serif` | 'Sofia Pro', BlinkMacSystemFont, -apple-system, 'Segoe UI','Helvetica Neue', 'Helvetica', 'Arial', sans-serif | The primary font stack used across our whole system. |

### Text sizes

#### Default / Mobile text sizes
| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$size-1` | `2.25rem` | Title/Headline 1 (on mobile) |
| `$size-2` | `2rem` | Title/Headline 2 (on mobile) |
| `$size-3` | `1.75rem` | Title/Headline 3 (on mobile) |
| `$size-4` | `1.5rem` | Title/Headline 4 (on mobile) |
| `$size-5` | `1.25rem` | Title/Headline 5 (on mobile) |
| `$size-6` | `1rem` | Default body copy - Title/Headline 6 (on mobile) |
| `$size-7` | `0.875rem` | Small body copy |
| `$size-8` | `0.75rem` | Smallest body copy |

#### Desktop text sizes
| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$font-size-title-1-desktop` | `3rem` | Title/Headline 1 on desktop |
| `$font-size-title-2-desktop` | `2.5rem` | Title/Headline 2 on desktop |
| `$font-size-title-3-desktop` | `2.25rem` | Title/Headline 3 on desktop |
| `$font-size-title-4-desktop` | `1.75rem` | Title/Headline 4 on desktop |
| `$font-size-title-5-desktop` | `1.5rem` | Title/Headline 5 on desktop |
| `$font-size-title-6-desktop` | `1.25rem` | Title/Headline 6 on desktop |

### Text weight
| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$weight-black` | `900` | - |
| `$weight-bold` | `700` | - |
| `$weight-semibold` | `600` | - |
| `$weight-normal` | `400` | - |

## Border & Radius
| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$border-width` | `2px` | Default border width for all borders |
| `$radius-small` | `4px` | Small border radius |
| `$radius` | `8px` | Default border radius |
| `$radius-large` | `16px` | Large border radius |



## Responsive Breakpoint Mixins

See full Bulma docs: https://bulma.io/documentation/utilities/responsive-mixins/

| Mixin Name | Value | Description / Use Case |
| --- | --- | --- |
| `@include mobile {}` | - | `max-width` - Applied on all screens smaller than the `$tablet` value - iPad and smaller. |
| `@include touch {}` | - | `max-width` - Applied on all screens smaller than the `$desktop` value - mobile and tablet. |
| `@include desktop {}` | - | `min-width` - Applied on all screens starting at the `$desktop` value - desktop and larger |
| `@include widescreen {}` | - | `min-width` - Applied on all screens starting at the `$widescreen` value - widescreen and larger |
| `@include fullhd {}` | - | `min-width` - Applied on all screens starting at the `$fullhd` value - fullhd and larger |

NOTE: You can append `-only` to any of these mixin names to only apply on that specific screen size and no other screen sizes. i.e. `@include tablet-only {}`, `@include desktop-only {}`, etc.


## Animation & Transitions

| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$speed` | `0.15s` | Default `transition` speed for hover, focus, etc. |
| `$hover-state-color-change-value` | `10%` | We default to either lightening or darkening colors (background, border, etc) by 10% upon hover/focus. |


## Box Shadows

| Variable Name | Value | Description / Use Case |
| --- | --- | --- |
| `$box-shadow-large` | `0px 12px 20px 0px rgba(0, 0, 0, 0.078)` | - |
| `$box-shadow-medium` | `0px 4px 12px 0px rgba(0, 0, 0, 0.121)` | - |
| `$box-shadow-small` | `0px 2px 4px 0px rgba(0, 0, 0, 0.16)` | - |
| `$box-shadow-popover` | `0px 0px 4px 0px rgba(0, 0, 0, 0.2)` | - |
